@@ -46,6 +46,12 @@
 
 #define SERVICE_LIST_TIMEOUT GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_SECONDS, 1)
 
+/**
+ * The GNUNET_GTK_file_sharing_downloads_tree_store with the
+ * information about active (or completed) downloads.
+ */
+GtkTreeStore *downloads_treestore;
+
 /**
  * Should gnunet-fs-gtk start in tray mode?
  */
@@ -700,6 +706,7 @@ run (void *cls, const struct GNUNET_SCHEDULER_TaskContext *tc)
 
   main_context.search_entry = GTK_ENTRY (GNUNET_FS_GTK_get_main_window_object ("main_window_search_entry"));
 
+  downloads_treestore = GTK_TREE_STORE (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_file_sharing_downloads_tree_store"));
   main_context.anonymity_combo = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object ("main_window_search_anonymity_combobox"));
   main_context.anonymity_level_liststore = GTK_LIST_STORE (GNUNET_FS_GTK_get_main_window_object ("anonymity_level_liststore"));
 
