@@ -4,7 +4,7 @@
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
-     by the Free Software Foundation; either version 2, or (at your
+     by the Free Software Foundation; either version 3, or (at your
      option) any later version.
 
      GNUnet is distributed in the hope that it will be useful, but
@@ -28,10 +28,146 @@
 
 #include "gnunet_gtk.h"
 #include <gnunet/gnunet_fs_service.h>
+#include <gnunet/gnunet_gns_service.h>
+#include <gnunet/gnunet_identity_service.h>
+#include <gnunet/gnunet_namestore_service.h>
 #include <extractor.h>
 
+
+/**
+ * Context for a GNS lookup for starting a search.
+ */
+struct SearchLookup
+{
+
+  /**
+   * This is a DLL.
+   */
+  struct SearchLookup *prev;
+
+  /**
+   * This is a DLL.
+   */
+  struct SearchLookup *next;
+
+  /**
+   * Our active request with GNS.
+   */
+  struct GNUNET_GNS_LookupRequest *gns;
+
+  /**
+   * Keywords to use.
+   */
+  gchar *keywords;
+
+  /**
+   * Task to trigger timeout.
+   */
+  GNUNET_SCHEDULER_TaskIdentifier timeout_task;
+
+  /**
+   * Desired anonymity level.
+   */
+  guint anonymity_level;
+
+};
+
+
+/**
+ * Context we keep for a pseudonym lookup on 'save'.
+ */
+struct PseuLookupContext
+{
+
+  /**
+   * Kept in a DLL.
+   */
+  struct PseuLookupContext *next;
+
+  /**
+   * Kept in a DLL.
+   */
+  struct PseuLookupContext *prev;
+
+  /**
+   * Main window context.
+   */
+  struct GNUNET_GTK_MainWindowContext *main_ctx;
+
+  /**
+   * Lookup request with GNS.
+   */
+  struct GNUNET_GNS_LookupRequest *lr;
+
+  /**
+   * Builder for the progress dialog that is displayed.
+   */
+  GtkBuilder *progress_dialog_builder;
+
+  /**
+   * The progress dialog itself.
+   */
+  GtkWidget *progress_dialog;
+
+  /**
+   * Builder for the nickname dialog that is displayed.
+   */
+  GtkBuilder *nick_dialog_builder;
+
+  /**
+   * The nick dialog itself.
+   */
+  GtkWidget *nick_dialog;
+
+  /**
+   * Handle to the namestore.
+   */
+  struct GNUNET_NAMESTORE_Handle *namestore;
+
+  /**
+   * Handle to our namestore request.
+   */
+  struct GNUNET_NAMESTORE_QueueEntry *qe;
+
+  /**
+   * Public key of the namespace we are trying to save.
+   */
+  struct GNUNET_CRYPTO_EcdsaPublicKey pkey;
+
+  /**
+   * Nickname we're saving under.
+   */
+  char *nick;
+
+};
+
+
+/**
+ * Abort the given search lookup.
+ *
+ * @param sl lookup to abort.
+ */
+void
+abort_search_lookup (struct SearchLookup *sl);
+
+
+/**
+ * Abort the given PSEU lookup.
+ *
+ * @param lctx lookup to abort.
+ */
+void
+abort_pseu_lookup (struct PseuLookupContext *lctx);
+
+
+/**
+ * Context for the main window.
+ */
 struct GNUNET_GTK_MainWindowContext
 {
+  /**
+   * Builder that loaded the main window.
+   */
   GtkBuilder *builder;
 
   const struct GNUNET_CONFIGURATION_Handle *cfg;
@@ -55,10 +191,13 @@ struct GNUNET_GTK_MainWindowContext
 
   GtkTreeRowReference *ns_selector_pushed_row;
   GtkTreeRowReference *selected_ns_row;
-  int ns_callback_registered;
+  struct GNUNET_FS_Pseudonym_DiscoveryHandle *ns_discovery_handle;
   GtkWindow *ns_manager;
   gulong ns_manager_delete_handler_id;
 
+  GtkWindow *ns_organizer;
+  gulong ns_organizer_delete_handler_id;
+
   GtkFileChooser *download_location_chooser;
   GtkEntry *download_name_entry;
   GtkComboBox *download_anonymity_combo;
@@ -67,6 +206,55 @@ struct GNUNET_GTK_MainWindowContext
   GtkVBox *download_panel;
 
   GtkNotebook *notebook;
+
+  GtkImage *connection_indicator;
+
+  /**
+   * Handle to the GNS service.
+   */
+  struct GNUNET_GNS_Handle *gns;
+
+  /**
+   * Handle to a zone monitor to update the namespace's drop-down list store.
+   * Monitors the @e sks_zone. Can be NULL.
+   */
+  struct GNUNET_NAMESTORE_ZoneMonitor *zm;
+
+  /**
+   * Head of sl DLL.
+   */
+  struct SearchLookup *sl_head;
+
+  /**
+   * Tail of sl DLL.
+   */
+  struct SearchLookup *sl_tail;
+
+  /**
+   * Head of lctx DLL.
+   */
+  struct PseuLookupContext *lctx_head;
+
+  /**
+   * Tail of lctx DLL.
+   */
+  struct PseuLookupContext *lctx_tail;
+
+  /**
+   * Handle to identity service.
+   */
+  struct GNUNET_IDENTITY_Handle *identity;
+
+  /**
+   * Operation we use to determine namespace resolution domain.
+   */
+  struct GNUNET_IDENTITY_Operation *id_op;
+
+  /**
+   * Our zone for SKS operations.  Can be NULL.
+   */
+  struct GNUNET_CRYPTO_EcdsaPrivateKey *sks_zone;
+
 };
 
 
@@ -84,12 +272,12 @@ enum GNUNET_GTK_FS_MAIN_WINDOW_SearchNamespaceModelColumns
      * A gpointer.
      */
     GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_KEY = 1,
-    
+
     /**
      * A gchararray.
      */
     GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_ROOT = 2,
-    
+
     /**
      * A gchararray.
      */
@@ -111,12 +299,12 @@ enum GNUNET_GTK_FS_MAIN_WINDOW_MetaDataModelColumns
      * A guint.
      */
     GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_FORMAT = 1,
-    
+
     /**
      * A gchararray.
      */
     GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_TYPE_STRING = 2,
-    
+
     /**
      * A gchararray.
      */
@@ -124,28 +312,6 @@ enum GNUNET_GTK_FS_MAIN_WINDOW_MetaDataModelColumns
   };
 
 
-/**
- * Columns in the anonymity level model.
- */
-enum GNUNET_GTK_FS_MAIN_WINDOW_AnonymityLevelModelColumns
-  {
-    /**
-     * A gchararray.
-     */
-    GNUNET_GTK_FS_MAIN_WINDOW_ANONYMITY_LEVEL_MC_NAME = 0,
-
-    /**
-     * A guint.
-     */
-    GNUNET_GTK_FS_MAIN_WINDOW_ANONYMITY_LEVEL_MC_LEVEL = 1,
-    
-    /**
-     * A gchararray.
-     */
-    GNUNET_GTK_FS_MAIN_WINDOW_ANONYMITY_LEVEL_MC_COLOR = 2,
-  };
-
-
 /**
  * Columns in the search mime model.
  */
@@ -209,6 +375,14 @@ struct GNUNET_FS_Handle *
 GNUNET_FS_GTK_get_fs_handle (void);
 
 
+/**
+ * Remember FS handle if we don't have one yet.
+ *
+ * @param fsh file sharing handle to use
+ */
+void
+GNUNET_FS_GTK_set_fs_handle (struct GNUNET_FS_Handle *fsh);
+
 /**
  * Get an object from the main window.
  *
@@ -242,6 +416,7 @@ GNUNET_GTK_get_selected_anonymity_level (GtkBuilder * builder,
 gboolean
 GNUNET_GTK_get_selected_anonymity_combo_level (GtkComboBox *combo, guint *p_level);
 
+
 /**
  * Set the selected anonymity level.
  * For dialogue initialization.
@@ -267,8 +442,6 @@ GNUNET_GTK_select_anonymity_level (GtkBuilder * builder, gchar * combo_name,
 gboolean
 GNUNET_GTK_select_anonymity_combo_level (GtkComboBox *combo, guint sel_level);
 
-void
-GNUNET_GTK_main_window_refresh_ns_list (struct GNUNET_GTK_MainWindowContext *main_ctx);
 
 #endif
 /* end of gnunet-fs-gtk.h */
