@@ -4,7 +4,7 @@
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
-     by the Free Software Foundation; either version 2, or (at your
+     by the Free Software Foundation; either version 3, or (at your
      option) any later version.
 
      GNUnet is distributed in the hope that it will be useful, but
@@ -19,7 +19,7 @@
 */
 
 /**
- * @file src/fs/gnunet-fs-gtk_anonymtiy-widgets.c
+ * @file src/fs/gnunet-fs-gtk_anonymity-widgets.c
  * @author Christian Grothoff
  * @brief operations to manage user's anonymity level selections
  */
@@ -28,12 +28,13 @@
 #include "gnunet-fs-gtk_anonymity-widgets.h"
 #include <gdk/gdk.h>
 
+
 /**
  * Spin button is changed, update its color.  NOTE: This function will eventually
  * become obsolete as we migrate to the drop-down style of anonymity-level selection.
  *
  * @param w the spin button that changed
- * @param builder's closure, unused
+ * @param data the builder's closure, unused
  */
 void
 GNUNET_GTK_anonymity_spin_button_value_changed_cb (GtkWidget * w, gpointer data)
@@ -73,56 +74,6 @@ GNUNET_GTK_anonymity_spin_button_value_changed_cb (GtkWidget * w, gpointer data)
 }
 
 
-/**
- * Obtain the numeric anonymity level selected by a GtkComboBox.
- *
- * @param builder builder for looking up widgets
- * @param combo_name name of the GtkComboBox with the anonymity selection
- * @param p_level where to store the anonymity level
- * @return TRUE on success, FALSE on failure
- */
-gboolean
-GNUNET_GTK_get_selected_anonymity_level (GtkBuilder * builder,
-                                         gchar * combo_name, guint * p_level)
-{
-  GtkComboBox *combo;
-
-  combo = GTK_COMBO_BOX (gtk_builder_get_object (builder, combo_name));
-  if (!combo)
-    return FALSE;
-  return GNUNET_GTK_get_selected_anonymity_combo_level (combo, p_level);
-}
-
-
-/**
- * Obtain the numeric anonymity level selected by a GtkComboBox.
- *
- * @param combo the GtkComboBox with the anonymity selection
- * @param p_level where to store the anonymity level
- * @return TRUE on success, FALSE on failure
- */
-gboolean
-GNUNET_GTK_get_selected_anonymity_combo_level (GtkComboBox *combo, guint *p_level)
-{
-  GtkTreeIter iter;
-  GtkTreeModel *model;
-  guint level;
-
-  if (! gtk_combo_box_get_active_iter (combo, &iter))
-    return FALSE;
-  model = gtk_combo_box_get_model (combo);
-  if (!model)
-    return FALSE;
-  gtk_tree_model_get (model, &iter,
-                      GNUNET_GTK_FS_MAIN_WINDOW_ANONYMITY_LEVEL_MC_LEVEL,
-                      &level,
-                      -1);
-  if (p_level)
-    *p_level = level;
-  return TRUE;
-}
-
-
 /**
  * Set the anonymity level displayed by a combo box.
  *
@@ -166,7 +117,7 @@ GNUNET_GTK_select_anonymity_combo_level (GtkComboBox *combo, guint sel_level)
   do
   {
     gtk_tree_model_get (model, &iter,
-                        GNUNET_GTK_FS_MAIN_WINDOW_ANONYMITY_LEVEL_MC_LEVEL,
+                        GNUNET_GTK_ANONYMITY_LEVEL_MC_LEVEL,
                         &level,
                         -1);
     if (level == sel_level)
@@ -174,7 +125,7 @@ GNUNET_GTK_select_anonymity_combo_level (GtkComboBox *combo, guint sel_level)
       gtk_combo_box_set_active_iter (combo, &iter);
       return TRUE;
     }
-  } 
+  }
   while (gtk_tree_model_iter_next (model, &iter));
   return FALSE;
 }
