@@ -4,7 +4,7 @@
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
-     by the Free Software Foundation; either version 2, or (at your
+     by the Free Software Foundation; either version 3, or (at your
      option) any later version.
 
      GNUnet is distributed in the hope that it will be useful, but
@@ -28,18 +28,19 @@
 #include "gnunet-fs-gtk.h"
 #include "gnunet-fs-gtk_event-handler.h"
 
+
 /**
- * Converts metadata specified by @data of size @data_len
- * and saved in format @format to UTF-8 encoded string.
+ * Converts metadata specified by @a data of size @a data_len
+ * and saved in format @a format to UTF-8 encoded string.
  * Works only for C-string and UTF8 metadata formats
  * (returns NULL for everything else).
  * Verifies UTF-8 strings.
  *
- * @param format format of the @data
+ * @param format format of the @a data
  * @param data data to convert
- * @param data_len length of the data buffer (in bytes)
+ * @param data_len length of the @a data buffer (in bytes)
  * @return NULL if can't be converted, allocated string otherwise,
- *         freeable with GNUNET_free* ().
+ *         freeable with #GNUNET_free.
  */
 char *
 GNUNET_FS_GTK_dubious_meta_to_utf8 (enum EXTRACTOR_MetaFormat format,
@@ -53,11 +54,11 @@ GNUNET_FS_GTK_dubious_meta_to_utf8 (enum EXTRACTOR_MetaFormat format,
       return GNUNET_strdup (data);
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
 		_("Failed to validate supposedly utf-8 string `%s' of length %u, assuming it to be a C string\n"),
-		data, 
+		data,
 		(unsigned int) data_len);
     format = EXTRACTOR_METAFORMAT_C_STRING;
     /* fall-through */
-  case EXTRACTOR_METAFORMAT_C_STRING:  
+  case EXTRACTOR_METAFORMAT_C_STRING:
     if (data_len > 0)
     {
       /* There are no guarantees that data is NULL-terminated, AFAIU,
@@ -82,7 +83,7 @@ GNUNET_FS_GTK_dubious_meta_to_utf8 (enum EXTRACTOR_MetaFormat format,
  *
  * @param cls closure (the GtkListStore)
  * @param plugin_name name of the plugin that produced this value;
- *        special values can be used (i.e. '<zlib>' for zlib being
+ *        special values can be used (i.e. '\<zlib\>' for zlib being
  *        used in the main libextractor library and yielding
  *        meta data).
  * @param type libextractor-type describing the meta data
@@ -90,7 +91,7 @@ GNUNET_FS_GTK_dubious_meta_to_utf8 (enum EXTRACTOR_MetaFormat format,
  * @param data_mime_type mime-type of data (not of the original file);
  *        can be NULL (if mime-type is not known)
  * @param data actual meta-data found
- * @param data_len number of bytes in data
+ * @param data_len number of bytes in @a data
  * @return 0 to continue (always)
  */
 int
@@ -116,54 +117,11 @@ GNUNET_FS_GTK_add_meta_data_to_list_store (void *cls, const char *plugin_name,
                                      GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_VALUE,
                                      data_to_insert,
                                      -1);
-  GNUNET_free (data_to_insert); 
+  GNUNET_free (data_to_insert);
   return 0;
 }
 
 
-/**
- * Convert the year from the spin button to an expiration
- * time (on midnight, January 1st of that year).
- *
- * @param spin button with an expiration year
- * @return expiration time in the usual GNUnet format
- */
-struct GNUNET_TIME_Absolute
-GNUNET_FS_GTK_get_expiration_time (GtkSpinButton * spin)
-{
-  struct GNUNET_TIME_Absolute ret;
-  int year;
-
-  year = gtk_spin_button_get_value_as_int (spin);
-  GNUNET_assert (year >= 0);
-  ret = GNUNET_FS_year_to_time ((unsigned int) year);
-  GNUNET_break (GNUNET_TIME_absolute_get ().abs_value < ret.abs_value);
-  return ret;
-}
-
-
-/**
- * Initialize the 'expiration_year_adjustment' of the given
- * builder to have a lower range of current-year+1 and a
- * default of current-year+2.
- *
- * @param builder builder object for which we should manipulate
- * the adjustment
- */
-void
-GNUNET_FS_GTK_setup_expiration_year_adjustment (GtkBuilder * builder)
-{
-  GtkAdjustment *aj;
-  unsigned int year;
-
-  year = GNUNET_FS_get_current_year ();
-  aj = GTK_ADJUSTMENT (gtk_builder_get_object
-                       (builder, "expiration_year_adjustment"));
-  gtk_adjustment_set_value (aj, year + 2);
-  gtk_adjustment_set_lower (aj, year + 1);
-}
-
-
 /**
  * Obtain pixbuf from thumbnail data in meta data.
  *
@@ -196,13 +154,13 @@ GNUNET_FS_GTK_get_thumbnail_from_meta_data (const struct
 
 
 /**
- * mmap the given file and run the GNUNET_FS_directory_list_contents
+ * mmap the given file and run the #GNUNET_FS_directory_list_contents
  * function on it.
  *
  * @param filename name with the directory
  * @param dep function to call on each entry
- * @param dep_cls closure for 'dep'
- * @return GNUNET_OK on success
+ * @param dep_cls closure for @a dep
+ * @return #GNUNET_OK on success
  */
 int
 GNUNET_FS_GTK_mmap_and_scan (const char *filename,
@@ -260,13 +218,13 @@ GNUNET_FS_GTK_mmap_and_scan (const char *filename,
  * the respective meta data.
  *
  * @param meta meta data to inspect
- * @param is_a_dup is set to GNUNET_YES if the result is a dup, and there was
- *        no description to be found. GNUNET_NO otherwise.
+ * @param is_a_dup is set to #GNUNET_YES if the result is a dup, and there was
+ *        no description to be found. #GNUNET_NO otherwise.
  * @return description of the result in utf-8, never NULL
  */
 char *
-GNUNET_FS_GTK_get_description_from_metadata (
-    const struct GNUNET_CONTAINER_MetaData *meta, int *is_a_dup)
+GNUNET_FS_GTK_get_description_from_metadata (const struct GNUNET_CONTAINER_MetaData *meta,
+					     int *is_a_dup)
 {
   char *desc;
   char *utf8_desc;
@@ -315,36 +273,25 @@ void
 GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
 			  guint anonymity_level)
 {
-  GtkTreeIter iter;
-  GtkTreeModel *namespace_treestore;
-  GtkTreeView *namespace_tree;
-  gchar *value;
-  GtkLabel *sel_namespace_label;
-  GtkTreePath *treepath;
   GtkEntry *query_entry;
-  struct GNUNET_HashCode *nsid;
-  struct GNUNET_HashCode want;
-  
+  GtkComboBox *ns_cb;
+  GtkEntry *ns_entry;
+  struct GNUNET_CRYPTO_EcdsaPublicKey want;
+
+
   if (GNUNET_FS_uri_test_chk (uri) || GNUNET_FS_uri_test_loc (uri))
   {
     struct DownloadEntry *de;
 
-    de = GNUNET_malloc (sizeof (struct DownloadEntry));
+    de = GNUNET_new (struct DownloadEntry);
     de->anonymity = anonymity_level;
     de->uri = GNUNET_FS_uri_dup (uri);
     GNUNET_FS_GTK_open_download_as_dialog (de);
     return;
   }
   query_entry = GTK_ENTRY (GNUNET_FS_GTK_get_main_window_object ("main_window_search_entry"));
-  namespace_tree =
-    GTK_TREE_VIEW (GNUNET_FS_GTK_get_main_window_object
-		   ("namespace_selector_treeview"));
-  namespace_treestore =
-    GTK_TREE_MODEL (GNUNET_FS_GTK_get_main_window_object
-		    ("main_window_search_namespace_treestore"));
-  sel_namespace_label =
-    GTK_LABEL (GNUNET_FS_GTK_get_main_window_object ("main_window_search_selected_namespace_label"));
-  
+  ns_cb = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object ("main_window_search_namespace_combobox"));
+  ns_entry = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (ns_cb)));
   if (GNUNET_FS_uri_test_sks (uri))
   {
     /* select the namespace */
@@ -354,43 +301,13 @@ GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
       GNUNET_break (0);
       return;
     }
-    if (! gtk_tree_model_get_iter_first (namespace_treestore, &iter))
     {
-      GNUNET_break (0);
-      return;
-    }
-    gtk_tree_model_get (namespace_treestore, &iter,
-                        GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_KEY,
-                        &nsid,
-                        -1);
-    while ( ( (NULL == nsid) ||
-	      (0 != memcmp (nsid,
-			    &want,
-			    sizeof (struct GNUNET_HashCode))) ) &&
-	    (gtk_tree_model_iter_next (namespace_treestore, &iter)) )
-      gtk_tree_model_get (namespace_treestore, &iter,
-                          GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_KEY,
-                          &nsid,
-                          -1);
-    if ( (NULL == nsid) ||
-	 (0 != memcmp (nsid,
-		       &want,
-		       sizeof (struct GNUNET_HashCode))) )
-    {
-      /* namespace unknown / not in list!? */
-      GNUNET_break (0);
-      return;
-    }    
-    gtk_tree_selection_select_iter (gtk_tree_view_get_selection
-				    (namespace_tree), &iter);
-    treepath = gtk_tree_model_get_path (namespace_treestore, 
-					&iter);
-    if (GNUNET_GTK_get_tree_string (namespace_tree, treepath,
-                                    GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_NAME,
-                                    &value))
-      gtk_label_set_text (sel_namespace_label, value);
-    gtk_tree_path_free (treepath);          
+      const char *ns_zkey;
 
+      ns_zkey = GNUNET_GNSRECORD_pkey_to_zkey (&want);
+      gtk_entry_set_text (ns_entry,
+			  ns_zkey);
+    }
     /* set search entry to the namespace identifier */
     {
       char *query_string;
@@ -398,33 +315,21 @@ GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
       query_string = GNUNET_FS_uri_sks_get_content_id (uri);
       gtk_entry_set_text (query_entry,
 			  query_string);
-      GNUNET_free (query_string);    
+      GNUNET_free (query_string);
     }
     return;
   }
 
   if (GNUNET_FS_uri_test_ksk (uri))
   {
-    /* select "no" namespace, which should be the first entry
-       in the namespace */
-    if (gtk_tree_model_get_iter_first (namespace_treestore, &iter))
-    {
-      gtk_tree_selection_select_iter (gtk_tree_view_get_selection
-				      (namespace_tree), &iter);
-      treepath = gtk_tree_model_get_path (namespace_treestore, &iter);
-      if (GNUNET_GTK_get_tree_string (namespace_tree, treepath,
-                                      GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_NAME,
-                                      &value))
-	gtk_label_set_text (sel_namespace_label, value);
-      gtk_tree_path_free (treepath);      
-    }
+    gtk_entry_set_text (ns_entry, "");
     /* set search entry to the query string */
     {
       char *query_string;
 
       query_string = GNUNET_FS_uri_ksk_to_string_fancy (uri);
       gtk_entry_set_text (query_entry,
-			  query_string);  
+			  query_string);
       GNUNET_free (query_string);
     }
     return;
@@ -433,73 +338,16 @@ GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
 }
 
 
-/* Largest rating value among all namespaces. INT_MIN means "undefined" */
-static int largest_namespace_rating = INT_MIN;
-
-
-/**
- * Helper function for finding the largest namespace rating.
- *
- * @param cls closure
- * @param pseudonym pseudonym hash
- * @param md metadata container
- * @param rating rating
- * @return GNUNET_OK to keep iterating
- */
-static int
-find_largest_namespace_rating_iterator (void *cls,
-    const struct GNUNET_HashCode *pseudonym, const char *name,
-    const char *unique_name,
-    const struct GNUNET_CONTAINER_MetaData *md, int rating)
-{
-  int *largest = cls;
-  if (*largest < rating)
-    *largest = rating;
-  return GNUNET_OK;
-}
-
-/**
- * Finds largest namespace rating.
- * Used to calculate a rating for newly discovered namespaces.
- * Returns from cache, if possible.
- *
- * @return largest namespace rating. Might be negative and even. INT_MIN means
- *         that no namespaces are known.
- */
-int
-GNUNET_GTK_find_largest_namespace_rating ()
-{
-  if (largest_namespace_rating != INT_MIN)
-    return largest_namespace_rating;
-  (void) GNUNET_PSEUDONYM_list_all (GNUNET_FS_GTK_get_configuration (),
-      find_largest_namespace_rating_iterator, &largest_namespace_rating);
-  return largest_namespace_rating;
-}
-
-/**
- * Sets largest namespace rating.
- * Used to change cached largest namespace rating, when namespace list
- * was changed in a way that is easy to track.
- * If namespace list was changed in a way that makes it difficult to
- * decide upon the new value, set new value to INT_MIN.
- *
- * @param new_value new value for the rating.
- */
-void
-GNUNET_GTK_set_largest_namespace_rating (int new_value)
-{
-  largest_namespace_rating = new_value;
-}
-
 /**
  * Converts a GtkTreeRowReference to a GtkTreeIter.
  *
  * @param rr row reference
  * @param iter pointer to an iter structure to fill
- * @return GNUNET_OK if iter was filled, GNUNET_SYSERR otherwise
+ * @return #GNUNET_OK if iter was filled, #GNUNET_SYSERR otherwise
  */
 int
-GNUNET_GTK_get_iter_from_reference (GtkTreeRowReference *rr, GtkTreeIter *iter)
+GNUNET_GTK_get_iter_from_reference (GtkTreeRowReference *rr,
+				    GtkTreeIter *iter)
 {
   int result = GNUNET_SYSERR;
   if (rr != NULL)
@@ -522,6 +370,7 @@ GNUNET_GTK_get_iter_from_reference (GtkTreeRowReference *rr, GtkTreeIter *iter)
   return result;
 }
 
+
 /**
  * Creates a GtkTreeRowReference from a GtkTreeIter.
  *
@@ -545,8 +394,29 @@ GNUNET_GTK_get_reference_from_iter (GtkTreeModel *model, GtkTreeIter *iter)
   return result;
 }
 
+
+/**
+ * Fills "next_iter" with iterator for an item that comes next in the tree
+ * after "iter".
+ * Next item is, in order of precedence:
+ * 1) First child of "iter", if "iter" has children and "allow_children"
+ *   is enabled.
+ * 2) Next sibling of "iter", unless "iter" is the last sibling.
+ * If none of those are present, function recursively checks parents of
+ *   "iter" until it finds next item or runs out of parents.
+ *
+ * @param model a model to reference
+ * @param iter an iter that points to current row in the model
+ * @param allow_children whether child of "iter" is considered to be next.
+ * @param next_iter will be filled with the next row in the model on success
+ * @return TRUE if next_iter is set to a valid iter,
+ *         FALSE if ran out of parents
+ */
 gboolean
-GNUNET_GTK_tree_model_get_next_flat_iter (GtkTreeModel *model, GtkTreeIter *iter, gboolean allow_children, GtkTreeIter *next_iter)
+GNUNET_GTK_tree_model_get_next_flat_iter (GtkTreeModel *model,
+					  GtkTreeIter *iter,
+					  gboolean allow_children,
+					  GtkTreeIter *next_iter)
 {
   GtkTreeIter current_iter = *iter;
   while (TRUE)
