@@ -4,7 +4,7 @@
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
-     by the Free Software Foundation; either version 2, or (at your
+     by the Free Software Foundation; either version 3, or (at your
      option) any later version.
 
      GNUnet is distributed in the hope that it will be useful, but
@@ -43,37 +43,13 @@ GNUNET_FS_GTK_get_thumbnail_from_meta_data (const struct
 
 
 /**
- * Initialize the 'expiration_year_adjustment' of the given
- * builder to have a lower range of current-year+1 and a
- * default of current-year+2.
- * FIXME-STYLE: odd API...
- *
- * @param builder builder object for which we should manipulate
- * the adjustment
- */
-void
-GNUNET_FS_GTK_setup_expiration_year_adjustment (GtkBuilder * builder);
-
-
-/**
- * Convert the year from the spin button to an expiration
- * time (on midnight, January 1st of that year).
- *
- * @param spin button with the year
- * @param time converted from the spin button
- */
-struct GNUNET_TIME_Absolute
-GNUNET_FS_GTK_get_expiration_time (GtkSpinButton * spin);
-
-
-/**
- * mmap the given file and run the GNUNET_FS_directory_list_contents
+ * mmap the given file and run the #GNUNET_FS_directory_list_contents
  * function on it.
  *
  * @param filename name with the directory
  * @param dep function to call on each entry
- * @param dep_cls closure for 'dep'
- * @return GNUNET_OK on success
+ * @param dep_cls closure for @a dep
+ * @return #GNUNET_OK on success
  */
 int
 GNUNET_FS_GTK_mmap_and_scan (const char *filename,
@@ -86,7 +62,7 @@ GNUNET_FS_GTK_mmap_and_scan (const char *filename,
  *
  * @param cls closure (the GtkListStore)
  * @param plugin_name name of the plugin that produced this value;
- *        special values can be used (i.e. '<zlib>' for zlib being
+ *        special values can be used (i.e. '\<zlib\>' for zlib being
  *        used in the main libextractor library and yielding
  *        meta data).
  * @param type libextractor-type describing the meta data
@@ -94,7 +70,7 @@ GNUNET_FS_GTK_mmap_and_scan (const char *filename,
  * @param data_mime_type mime-type of data (not of the original file);
  *        can be NULL (if mime-type is not known)
  * @param data actual meta-data found
- * @param data_len number of bytes in data
+ * @param data_len number of bytes in @a data
  * @return 0 to continue (always)
  */
 int
@@ -106,17 +82,17 @@ GNUNET_FS_GTK_add_meta_data_to_list_store (void *cls, const char *plugin_name,
 
 
 /**
- * Converts metadata specified by @data of size @data_len
- * and saved in format @format to UTF-8 encoded string.
+ * Converts metadata specified by @a data of size @a data_len
+ * and saved in format @a format to UTF-8 encoded string.
  * Works only for C-string and UTF8 metadata formats
  * (returns NULL for everything else).
  * Verifies UTF-8 strings.
  *
- * @param format format of the @data
+ * @param format format of the @a data
  * @param data data to convert
- * @param data_len length of the data buffer (in bytes)
+ * @param data_len length of the @a data buffer (in bytes)
  * @return NULL if can't be converted, allocated string otherwise,
- *         freeable with GNUNET_free* ().
+ *         freeable with GNUNET_free().
  */
 char *
 GNUNET_FS_GTK_dubious_meta_to_utf8 (enum EXTRACTOR_MetaFormat format,
@@ -129,13 +105,13 @@ GNUNET_FS_GTK_dubious_meta_to_utf8 (enum EXTRACTOR_MetaFormat format,
  * the respective meta data.
  *
  * @param meta meta data to inspect
- * @param is_a_dup is set to GNUNET_YES if the result is a dup, and there was
- *        no description to be found. GNUNET_NO otherwise.
+ * @param is_a_dup is set to #GNUNET_YES if the result is a dup, and there was
+ *        no description to be found. #GNUNET_NO otherwise.
  * @return description of the result in utf-8, never NULL
  */
 char *
-GNUNET_FS_GTK_get_description_from_metadata (
-    const struct GNUNET_CONTAINER_MetaData *meta, int *is_a_dup);
+GNUNET_FS_GTK_get_description_from_metadata (const struct GNUNET_CONTAINER_MetaData *meta,
+					     int *is_a_dup);
 
 
 /**
@@ -150,39 +126,17 @@ GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
 			  guint anonymity_level);
 
 
-/**
- * Finds largest namespace rating.
- * Used to calculate a rating for newly discovered namespaces.
- * Returns from cache, if possible.
- *
- * @return largest namespace rating. Might be negative and even. INT_MIN means
- *         that no namespaces are known.
- */
-int
-GNUNET_GTK_find_largest_namespace_rating (void);
-
-
-/**
- * Sets largest namespace rating.
- * Used to change cached largest namespace rating, when namespace list
- * was changed in a way that is easy to track.
- * If namespace list was changed in a way that makes it difficult to
- * decide upon the new value, set new value to INT_MIN.
- *
- * @param new_value new value for the rating.
- */
-void
-GNUNET_GTK_set_largest_namespace_rating (int new_value);
-
 /**
  * Converts a GtkTreeRowReference to a GtkTreeIter.
  *
  * @param rr row reference
  * @param iter pointer to an iter structure to fill
- * @return GNUNET_OK if iter was filled, GNUNET_SYSERR otherwise
+ * @return #GNUNET_OK if iter was filled, #GNUNET_SYSERR otherwise
  */
 int
-GNUNET_GTK_get_iter_from_reference (GtkTreeRowReference *rr, GtkTreeIter *iter);
+GNUNET_GTK_get_iter_from_reference (GtkTreeRowReference *rr,
+				    GtkTreeIter *iter);
+
 
 /**
  * Creates a GtkTreeRowReference from a GtkTreeIter.
@@ -192,7 +146,9 @@ GNUNET_GTK_get_iter_from_reference (GtkTreeRowReference *rr, GtkTreeIter *iter);
  * @return newly created reference or NULL in case of error
  */
 GtkTreeRowReference *
-GNUNET_GTK_get_reference_from_iter (GtkTreeModel *model, GtkTreeIter *iter);
+GNUNET_GTK_get_reference_from_iter (GtkTreeModel *model,
+				    GtkTreeIter *iter);
+
 
 /**
  * Fills "next_iter" with iterator for an item that comes next in the tree
@@ -213,7 +169,10 @@ GNUNET_GTK_get_reference_from_iter (GtkTreeModel *model, GtkTreeIter *iter);
  */
 gboolean
 GNUNET_GTK_tree_model_get_next_flat_iter (GtkTreeModel *model,
-    GtkTreeIter *iter, gboolean allow_children, GtkTreeIter *next_iter);
+					  GtkTreeIter *iter,
+					  gboolean allow_children,
+					  GtkTreeIter *next_iter);
+
 
 #endif
 /* end of gnunet-fs-gtk-common.h */
