@@ -4,7 +4,7 @@
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
-     by the Free Software Foundation; either version 2, or (at your
+     by the Free Software Foundation; either version 3, or (at your
      option) any later version.
 
      GNUnet is distributed in the hope that it will be useful, but
@@ -38,7 +38,7 @@
  *
  * @param uris string we got
  * @param anonymity_level anonymity level to use
- * @return GNUNET_OK on success, GNUNET_NO if the URI type is not supported, GNUNET_SYSERR if we failed to
+ * @return #GNUNET_OK on success, #GNUNET_NO if the URI type is not supported, #GNUNET_SYSERR if we failed to
  *         parse the URI
  */
 int
@@ -61,9 +61,9 @@ GNUNET_FS_GTK_handle_uri_string (const char *uris,
 
 /**
  * User selected "execute" in the open-URI dialog.
- * 
+ *
  * @param button the execute button
- * @param user_data the 'GtkBuilder' of the URI dialog
+ * @param user_data the `GtkBuilder` of the URI dialog
  */
 void
 GNUNET_GTK_open_url_dialog_execute_button_clicked_cb (GtkButton * button,
@@ -88,24 +88,24 @@ GNUNET_GTK_open_url_dialog_execute_button_clicked_cb (GtkButton * button,
 
   uris = gtk_text_buffer_get_text (tb, &ti_start, &ti_end, FALSE);
   if (!GNUNET_GTK_get_selected_anonymity_level
-      (builder, "main_window_search_anonymity_combobox", &anonymity_level))
+      (builder, "GNUNET_GTK_open_url_dialog_anonymity_combobox", &anonymity_level))
   {
     GNUNET_break (0);
     gtk_widget_destroy (dialog);
-    g_object_unref (G_OBJECT (builder));  
+    g_object_unref (G_OBJECT (builder));
     return;
   }
   GNUNET_break (GNUNET_OK ==
 		GNUNET_FS_GTK_handle_uri_string (uris, anonymity_level));
-  g_free (uris); 
+  g_free (uris);
   gtk_widget_destroy (dialog);
-  g_object_unref (G_OBJECT (builder));  
+  g_object_unref (G_OBJECT (builder));
 }
 
 
 /**
  * User selected "cancel" in the open-URI dialog.
- * 
+ *
  * @param button the cancel button
  * @param user_data the 'GtkBuilder' of the URI dialog
  */
@@ -117,7 +117,7 @@ GNUNET_GTK_open_url_dialog_cancel_button_clicked_cb (GtkButton * button,
   GtkWidget *dialog;
 
   dialog = GTK_WIDGET (gtk_builder_get_object
-		       (builder, 
+		       (builder,
 			"GNUNET_GTK_open_url_window"));
   gtk_widget_destroy (GTK_WIDGET (dialog));
   g_object_unref (G_OBJECT (builder));
@@ -126,7 +126,7 @@ GNUNET_GTK_open_url_dialog_cancel_button_clicked_cb (GtkButton * button,
 
 /**
  * User closed the window of the open-URI dialog.
- * 
+ *
  * @param widget the window
  * @param event the deletion event
  * @param user_data the 'GtkBuilder' of the URI dialog
@@ -147,7 +147,7 @@ GNUNET_GTK_open_url_window_delete_event_cb (GtkWidget * widget,
 /**
  * User pushed a key in the open-URI dialog, check if we currently
  * have valid URI and if the key was 'RETURN', run the action.
- * 
+ *
  * @param widget the window
  * @param event the deletion event
  * @param user_data the 'GtkBuilder' of the URI dialog
@@ -163,7 +163,7 @@ GNUNET_GTK_open_url_dialog_url_textview_key_press_event_cb (GtkWidget * widget,
   if (event->keyval != GDK_KEY_Return)
     return FALSE;
   execute = GTK_WIDGET (gtk_builder_get_object (builder,
-						"GNUNET_GTK_open_url_dialog_execute_button"));  
+						"GNUNET_GTK_open_url_dialog_execute_button"));
   if (gtk_widget_get_sensitive (execute))
     GNUNET_GTK_open_url_dialog_execute_button_clicked_cb (GTK_BUTTON (execute),
 							  user_data);
@@ -174,7 +174,7 @@ GNUNET_GTK_open_url_dialog_url_textview_key_press_event_cb (GtkWidget * widget,
 /**
  * User edited the URI of the open-URI dialog, check if it is currently
  * a valid URI and update the sensitivity of the 'execute' button accordingly.
- * 
+ *
  * @param textbuffer the updated buffer
  * @param user_data the 'GtkBuilder' of the URI dialog
  */
@@ -240,7 +240,7 @@ GNUNET_GTK_main_menu_file_download_uri_activate_cb (GtkWidget * dummy,
     return;
   }
   dialog = GTK_WIDGET (gtk_builder_get_object
-		       (builder, 
+		       (builder,
 			"GNUNET_GTK_open_url_window"));
   tb = GTK_TEXT_BUFFER (gtk_builder_get_object
                         (builder,
@@ -251,7 +251,7 @@ GNUNET_GTK_main_menu_file_download_uri_activate_cb (GtkWidget * dummy,
 
   /* FIXME-FEATURE: query the clipboard, maybe there's valid URI in there?
    * If so, get it. */
-  combo = GTK_COMBO_BOX (gtk_builder_get_object 
+  combo = GTK_COMBO_BOX (gtk_builder_get_object
 			 (builder,
 			  "GNUNET_GTK_open_url_dialog_anonymity_combobox"));
   gtk_combo_box_set_model (combo, GNUNET_FS_GTK_get_anonymity_level_list_store ());
