@@ -1,10 +1,10 @@
 /*
      This file is part of GNUnet
-     (C) 2005, 2006, 2010, 2012 Christian Grothoff (and other contributing authors)
+     (C) 2005-2013 Christian Grothoff (and other contributing authors)
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
-     by the Free Software Foundation; either version 2, or (at your
+     by the Free Software Foundation; either version 3, or (at your
      option) any later version.
 
      GNUnet is distributed in the hope that it will be useful, but
@@ -84,7 +84,7 @@ enum PUBLISH_MetadataTypesModelColumns
     /**
      * A gchararray.
      */
-    PUBLISH_METADATA_TYPES_MC_DESCRIPTION = 3,
+    PUBLISH_METADATA_TYPES_MC_DESCRIPTION = 3
   };
 
 
@@ -101,7 +101,7 @@ enum PUBLISH_TypesModelColumns
     /**
      * A gchararray.
      */
-    PUBLISH_TYPES_MC_TYPE_NAME = 1,
+    PUBLISH_TYPES_MC_TYPE_NAME = 1
   };
 
 
@@ -118,7 +118,7 @@ enum PUBLISH_KeywordsModelColumns
     /**
      * A gboolean.
      */
-    PUBLISH_TYPES_MC_ADDED = 1,
+    PUBLISH_TYPES_MC_ADDED = 1
   };
 
 
@@ -300,26 +300,26 @@ change_metatypes (struct EditPublicationDialogContext *ctx, gint code)
   /* double-check that 'code' is valid */
   for (pubtype_count = 0; NULL != types[pubtype_count]; pubtype_count++) ;
   GNUNET_assert (code < pubtype_count);
-  
+
   /* clear existing selection of metatypes */
   gtk_list_store_clear (ctx->metatypes_liststore);
   max_type = EXTRACTOR_metatype_get_max ();
   /* add new types based on selection */
-  for (i = 0; types[code][i] != EXTRACTOR_METATYPE_RESERVED; i++)  
+  for (i = 0; types[code][i] != EXTRACTOR_METATYPE_RESERVED; i++)
     if ( (types[code][i] < max_type) && (types[code][i] > 0) )
-      gtk_list_store_insert_with_values (ctx->metatypes_liststore, 
-                                         &iter, G_MAXINT, 
+      gtk_list_store_insert_with_values (ctx->metatypes_liststore,
+                                         &iter, G_MAXINT,
                                          PUBLISH_METADATA_TYPES_MC_TYPE,
-                                         types[code][i], 
+                                         types[code][i],
                                          PUBLISH_METADATA_TYPES_MC_FORMAT,
-                                         EXTRACTOR_METAFORMAT_UTF8, 
+                                         EXTRACTOR_METAFORMAT_UTF8,
                                          PUBLISH_METADATA_TYPES_MC_TYPE_NAME,
                                          EXTRACTOR_metatype_to_string
                                          (types [code][i]),
                                          PUBLISH_METADATA_TYPES_MC_DESCRIPTION,
                                          EXTRACTOR_metatype_to_description
-                                         (types[code][i]), 
-                                         -1);  
+                                         (types[code][i]),
+                                         -1);
 }
 
 
@@ -361,7 +361,7 @@ metadata_selection_changed_cb (GtkTreeSelection *ts,
   struct EditPublicationDialogContext *ctx = user_data;
 
   gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object
-					(ctx->builder, 
+					(ctx->builder,
 					 "GNUNET_GTK_edit_publication_delete_button")),
                             gtk_tree_selection_get_selected (ts, NULL, NULL));
 }
@@ -377,9 +377,9 @@ metadata_selection_changed_cb (GtkTreeSelection *ts,
  * @param new_text new value for the item
  * @param user_data the 'struct EditPublicationDialogContext'
  */
-void 
-GNUNET_GTK_edit_publication_metadata_tree_view_type_renderer_edited_cb (GtkCellRendererText *renderer, 
-									gchar * path, 
+void
+GNUNET_GTK_edit_publication_metadata_tree_view_type_renderer_edited_cb (GtkCellRendererText *renderer,
+									gchar * path,
 									gchar * new_text,
 									gpointer user_data)
 {
@@ -387,8 +387,8 @@ GNUNET_GTK_edit_publication_metadata_tree_view_type_renderer_edited_cb (GtkCellR
   GtkTreeIter iter;
   gint type_id;
 
-  if (! gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (ctx->meta_liststore), 
-					     &iter, 
+  if (! gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (ctx->meta_liststore),
+					     &iter,
 					     path))
   {
     GNUNET_break (0);
@@ -419,12 +419,12 @@ GNUNET_GTK_edit_publication_metadata_tree_view_type_renderer_edited_cb (GtkCellR
  * 'GNUNET_GTK_edit_publication_metadata_tree_view_type_renderer_edited_cb'.
  *
  * @param combo combo box that was dropped down
- * @param path which item was changed in the tree view
+ * @param path_string which item was changed in the tree view
  * @param new_iter item that is now selected in the drop-down combo box
- * @param user_data the 'struct EditPublicationDialogContext' 
+ * @param user_data the 'struct EditPublicationDialogContext'
  */
-void 
-GNUNET_GTK_edit_publication_metadata_tree_view_type_renderer_changed_cb (GtkCellRendererCombo * combo, 
+void
+GNUNET_GTK_edit_publication_metadata_tree_view_type_renderer_changed_cb (GtkCellRendererCombo * combo,
 									 gchar * path_string,
 									 GtkTreeIter * new_iter,
 									 gpointer user_data)
@@ -452,7 +452,7 @@ GNUNET_GTK_edit_publication_metadata_tree_view_type_renderer_changed_cb (GtkCell
  * @param new_text new value for the item
  * @param user_data the 'struct EditPublicationDialogContext'
  */
-void 
+void
 GNUNET_GTK_edit_publication_metadata_tree_view_value_renderer_edited_cb (GtkCellRendererText * renderer,
 									 gchar * path,
 									 gchar * new_text,
@@ -467,16 +467,16 @@ GNUNET_GTK_edit_publication_metadata_tree_view_value_renderer_edited_cb (GtkCell
   char *pos;
 
   if (! gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (ctx->meta_liststore),
-					     &iter, 
+					     &iter,
 					     path))
   {
     GNUNET_break (0);
     return;
   }
 
-  gtk_tree_model_get (GTK_TREE_MODEL (ctx->meta_liststore), &iter, 
+  gtk_tree_model_get (GTK_TREE_MODEL (ctx->meta_liststore), &iter,
                       PUBLISH_METADATA_MC_TYPE, &metatype, -1);
-  if (metatype == EXTRACTOR_METATYPE_GNUNET_ORIGINAL_FILENAME) 
+  if (metatype == EXTRACTOR_METATYPE_GNUNET_ORIGINAL_FILENAME)
   {
     /* apply filename rules */
     /* First, use UNIX-style separators */
@@ -493,16 +493,16 @@ GNUNET_GTK_edit_publication_metadata_tree_view_value_renderer_edited_cb (GtkCell
     }
 
     /* However, directories must end with '/', so add it */
-    if ( (new_text[strlen (new_text) - 1] != '/') && 
+    if ( (new_text[strlen (new_text) - 1] != '/') &&
 	 ctx->is_directory == GNUNET_YES)
     {
       char * tmp;
-      
+
       GNUNET_asprintf (&tmp, "%s/", avalue);
       GNUNET_free (avalue);
       avalue = tmp;
     }
-    
+
     /* Also, replace '../' everywhere with "___" */
     while (NULL != (pos = strstr (avalue, "../")))
       memset (pos, '_', 3);
@@ -514,8 +514,8 @@ GNUNET_GTK_edit_publication_metadata_tree_view_value_renderer_edited_cb (GtkCell
     ivalue = new_text;
     avalue = NULL;
   }
-  gtk_list_store_set (ctx->meta_liststore, &iter, 
-                      PUBLISH_METADATA_MC_VALUE, ivalue, 
+  gtk_list_store_set (ctx->meta_liststore, &iter,
+                      PUBLISH_METADATA_MC_VALUE, ivalue,
                       -1);
   GNUNET_free_non_null (avalue);
 }
@@ -553,7 +553,7 @@ GNUNET_GTK_edit_publication_add_button_clicked_cb (GtkButton * button,
  * The user has pushed the 'del' button for metadata.
  * If there is a metadata selected, remove it from the list store.
  *
- * @param widget the button
+ * @param button the delete button
  * @param user_data the 'struct EditPublicationDialogContext'
  */
 void
@@ -583,7 +583,7 @@ GNUNET_GTK_edit_publication_delete_button_clicked_cb (GtkButton * button,
  * @param user_data the 'struct EditPublicationDialogContext'
  */
 void
-GNUNET_GTK_edit_publication_metadata_preview_file_chooser_button_file_set_cb (GtkFileChooserButton * widget, 
+GNUNET_GTK_edit_publication_metadata_preview_file_chooser_button_file_set_cb (GtkFileChooserButton * widget,
 									      gpointer user_data)
 {
   struct EditPublicationDialogContext *ctx = user_data;
@@ -637,14 +637,14 @@ GNUNET_GTK_edit_publication_keyword_entry_changed_cb (GtkEditable * editable,
 
   keyword = gtk_entry_get_text (ctx->keyword_entry);
   gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (ctx->builder,
-								"GNUNET_GTK_edit_publication_keyword_list_add_button")), 
+								"GNUNET_GTK_edit_publication_keyword_list_add_button")),
 			    (strlen (keyword) > 0) ? TRUE : FALSE);
 }
 
 
 /**
- * Update the sensitivity of the 'confirm' button based on 
- * the availability of keywords and whether they are required or 
+ * Update the sensitivity of the 'confirm' button based on
+ * the availability of keywords and whether they are required or
  * not.
  *
  * @param ctx the 'struct EditPublicationDialogContext'
@@ -654,7 +654,7 @@ update_confirm_sensitivity (struct EditPublicationDialogContext *ctx)
 {
   GtkTreeIter iter;
 
-  if ( (! ctx->allow_no_keywords) && 
+  if ( (! ctx->allow_no_keywords) &&
        (! gtk_tree_model_get_iter_first (GTK_TREE_MODEL (ctx->keywords_liststore),
 					 &iter)) )
     gtk_widget_set_sensitive (ctx->confirm_button, FALSE);
@@ -667,14 +667,14 @@ update_confirm_sensitivity (struct EditPublicationDialogContext *ctx)
  * The user has pushed the 'del' button for the keyword.
  * If there is a keyword selected, remove it from the list store.
  *
- * @param widget the button
+ * @param button the button
  * @param user_data the 'struct EditPublicationDialogContext'
  */
 void
 GNUNET_GTK_edit_publication_keyword_list_del_button_clicked_cb (GtkButton *
                                                                 button,
                                                                 gpointer user_data)
-{ 
+{
   struct EditPublicationDialogContext *ctx = user_data;
   GtkTreeIter iter;
   GtkTreeSelection *keywords_selection;
@@ -697,7 +697,7 @@ GNUNET_GTK_edit_publication_keyword_list_del_button_clicked_cb (GtkButton *
  * The user has pushed the 'add' button for the keyword (or pressed RETURN).
  * If there is a keyword in the line, add it to the list store.
  *
- * @param widget the entry line, or NULL (if we are called from 'RETURN')
+ * @param button the add button, or NULL (if we are called from 'RETURN')
  * @param user_data the 'struct EditPublicationDialogContext'
  */
 void
@@ -712,7 +712,7 @@ GNUNET_GTK_edit_publication_keyword_list_add_button_clicked_cb (GtkButton *
   keyword = gtk_entry_get_text (ctx->keyword_entry);
   if (strlen (keyword) == 0)
     return;
-  gtk_list_store_insert_with_values (ctx->keywords_liststore, 
+  gtk_list_store_insert_with_values (ctx->keywords_liststore,
                                      &iter, G_MAXINT,
                                      PUBLISH_TYPES_MC_KEYWORD, keyword,
                                      PUBLISH_TYPES_MC_ADDED, TRUE,
@@ -729,6 +729,7 @@ GNUNET_GTK_edit_publication_keyword_list_add_button_clicked_cb (GtkButton *
  * @param widget the entry line
  * @param event the event information
  * @param user_data the 'struct EditPublicationDialogContext'
+ * @return TRUE if we handled the event, FALSE if not
  */
 gboolean
 GNUNET_GTK_edit_publication_keyword_entry_key_press_event_cb (GtkWidget *
@@ -802,7 +803,7 @@ GNUNET_GTK_edit_publication_window_delete_event_cb (GtkWidget * widget,
  *        field and the liststore to check the current value
  *        against in 'meta_liststore'.
  * @param plugin_name name of the plugin that produced this value;
- *        special values can be used (i.e. '<zlib>' for zlib being
+ *        special values can be used (i.e. '\<zlib\>' for zlib being
  *        used in the main libextractor library and yielding
  *        meta data).
  * @param type libextractor-type describing the meta data
@@ -883,13 +884,13 @@ preserve_meta_items (void *cls, const char *plugin_name,
  *        used in the main libextractor library and yielding
  *        meta data).
  * @param type libextractor-type describing the meta data
- * @param format basic format information about data 
+ * @param format basic format information about data
  * @param data_mime_type mime-type of data (not of the original file);
  *        can be NULL (if mime-type is not known)
  * @param data actual meta-data found
  * @param data_len number of bytes in data
  * @return 0 to continue extracting, 1 to abort
- */ 
+ */
 static int
 le_callback (void *cls,
 	     const char *plugin_name,
@@ -929,7 +930,7 @@ get_mime_type (const void *data,
     return NULL;
   ret = NULL;
   EXTRACTOR_extract (pl, NULL, data, data_size, &le_callback, &ret);
-  EXTRACTOR_plugin_remove_all (pl);  
+  EXTRACTOR_plugin_remove_all (pl);
   return ret;
 }
 
@@ -967,7 +968,7 @@ file_information_update (void *cls, struct GNUNET_FS_FileInformation *fi,
   bo->content_priority = gtk_spin_button_get_value (ctx->priority_spin);
   bo->replication_level = gtk_spin_button_get_value (ctx->replication_spin);
   year = gtk_spin_button_get_value (ctx->expiration_year_spin);
-  bo->expiration_time = GNUNET_FS_year_to_time (year);
+  bo->expiration_time = GNUNET_TIME_year_to_time (year);
 
   /* update keyword-URI */
   if (NULL != (*uri))
@@ -993,8 +994,8 @@ file_information_update (void *cls, struct GNUNET_FS_FileInformation *fi,
 
   /* update meta data; first, we copy the unchanged values from the original meta data */
   ctx->md = GNUNET_CONTAINER_meta_data_create ();
-  GNUNET_CONTAINER_meta_data_iterate (meta, 
-				      &preserve_meta_items, 
+  GNUNET_CONTAINER_meta_data_iterate (meta,
+				      &preserve_meta_items,
 				      ctx);
   /* clear original meta data */
   GNUNET_CONTAINER_meta_data_clear (meta);
@@ -1002,7 +1003,7 @@ file_information_update (void *cls, struct GNUNET_FS_FileInformation *fi,
   GNUNET_CONTAINER_meta_data_merge (meta, ctx->md);
   GNUNET_CONTAINER_meta_data_destroy (ctx->md);
   ctx->md = NULL;
-  /* now add all of the values from the model; adding will simply do 
+  /* now add all of the values from the model; adding will simply do
      nothing for values that are already in the set because they were preserved */
   if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (ctx->meta_liststore), &iter))
   {
@@ -1027,7 +1028,7 @@ file_information_update (void *cls, struct GNUNET_FS_FileInformation *fi,
     }
     while (gtk_tree_model_iter_next (GTK_TREE_MODEL (ctx->meta_liststore), &iter));
   }
-  
+
   /* finally, if we got a new preview, add it as well */
   if (ctx->preview_changed == GNUNET_YES)
   {
@@ -1057,7 +1058,7 @@ file_information_update (void *cls, struct GNUNET_FS_FileInformation *fi,
 	GFileInfo *finfo;
 	const char *gmime;
 	
-	finfo = g_file_query_info (f, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE, 
+	finfo = g_file_query_info (f, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
 				   0, NULL, NULL);
 	gmime = g_file_info_get_attribute_string (finfo,
 						  G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE);
@@ -1081,7 +1082,7 @@ file_information_update (void *cls, struct GNUNET_FS_FileInformation *fi,
 
 /**
  * The user clicked the 'confirm' button.  Push the edits back into the
- * FileInformation structure and given it and the options back to the 
+ * FileInformation structure and given it and the options back to the
  * callback.  Then clean up the dialog.
  *
  * @param button the cancel button
@@ -1094,11 +1095,11 @@ GNUNET_GTK_edit_publication_confirm_button_clicked_cb (GtkButton * button,
   struct EditPublicationDialogContext *ctx = user_data;
 
   /* push back changes to file-information */
-  GNUNET_FS_file_information_inspect (ctx->fip, 
+  GNUNET_FS_file_information_inspect (ctx->fip,
 				      &file_information_update,
 				      ctx);
   /* call our continuation */
-  ctx->cb (ctx->cb_cls, 
+  ctx->cb (ctx->cb_cls,
 	   GTK_RESPONSE_OK,
 	   gtk_entry_get_text (ctx->root_entry));
   /* free resources from the edit dialog */
@@ -1143,13 +1144,13 @@ add_keyword (void *cls, const char *keyword, int is_mandatory)
  *        used in the main libextractor library and yielding
  *        meta data).
  * @param type libextractor-type describing the meta data
- * @param format basic format information about data 
+ * @param format basic format information about data
  * @param data_mime_type mime-type of data (not of the original file);
  *        can be NULL (if mime-type is not known)
  * @param data actual meta-data found
  * @param data_len number of bytes in data
  * @return 0 to continue extracting, 1 to abort
- */ 
+ */
 static int
 set_window_title_to_filename (void *cls,
 			      const char *plugin_name,
@@ -1187,7 +1188,7 @@ set_window_title_to_filename (void *cls,
  * @return GNUNET_SYSERR (aborts after first call)
  */
 static int
-file_information_import (void *cls, 
+file_information_import (void *cls,
 			 struct GNUNET_FS_FileInformation *fi,
 			 uint64_t length,
 			 struct GNUNET_CONTAINER_MetaData *meta,
@@ -1200,7 +1201,7 @@ file_information_import (void *cls,
   int year;
 
   /* import options */
-  year = (int) GNUNET_FS_time_to_year (bo->expiration_time);
+  year = (int) GNUNET_TIME_time_to_year (bo->expiration_time);
   gtk_spin_button_set_value (ctx->expiration_year_spin, year);
   GNUNET_GTK_select_anonymity_combo_level (ctx->anonymity_combo,
 					   bo->anonymity_level);
@@ -1225,7 +1226,7 @@ file_information_import (void *cls,
       gtk_image_set_from_pixbuf (ctx->preview_image, pixbuf);
     }
   }
-  
+
   /* Also update window title based on filename */
   gtk_window_set_title (ctx->edit_publication_window, _("<unnamed>"));
   GNUNET_CONTAINER_meta_data_iterate (meta,
@@ -1293,7 +1294,7 @@ GNUNET_FS_GTK_edit_publish_dialog (GtkWindow * parent,
                       (ctx->builder,
                        "GNUNET_GTK_edit_publication_keyword_list_tree_view"));
   ctx->edit_publication_window =
-    GTK_WINDOW (gtk_builder_get_object (ctx->builder, 
+    GTK_WINDOW (gtk_builder_get_object (ctx->builder,
 					"GNUNET_GTK_edit_publication_window"));
   ctx->keywords_liststore = GTK_LIST_STORE (gtk_builder_get_object
                        (ctx->builder, "GNUNET_GTK_publication_keywords_liststore"));
@@ -1331,9 +1332,9 @@ GNUNET_FS_GTK_edit_publish_dialog (GtkWindow * parent,
 								"GNUNET_GTK_edit_publication_anonymity_combobox"));
 
   /* Basic initialization of widgets models and visibility */
-  gtk_combo_box_set_model (ctx->anonymity_combo, 
+  gtk_combo_box_set_model (ctx->anonymity_combo,
 			   GNUNET_FS_GTK_get_anonymity_level_list_store ());
-  GNUNET_FS_GTK_setup_expiration_year_adjustment (ctx->builder);
+  GNUNET_GTK_setup_expiration_year_adjustment (ctx->builder);
 
   pubtypes_combo =
       GTK_COMBO_BOX (gtk_builder_get_object
