@@ -58,7 +58,7 @@ get_path_from_proc_maps ()
   while (NULL != fgets (line, sizeof (line), f))
   {
     if ((1 ==
-         sscanf (line, "%*x-%*x %*c%*c%*c%*c %*x %*2u:%*2u %*u%*[ ]%s", dir)) &&
+         sscanf (line, "%*x-%*x %*c%*c%*c%*c %*x %*2x:%*2x %*u%*[ ]%s", dir)) &&
         (NULL != (lgu = strstr (dir, "libgnunetgtk.so"))))
     {
       lgu[0] = '\0';
@@ -94,7 +94,7 @@ get_path_from_proc_exe ()
   lnk[size] = '\0';
   while ((lnk[size] != '/') && (size > 0))
     size--;
- /* test for being in lib/gnunet/libexec/ */
+  /* test for being in lib/gnunet/libexec/ or lib/MULTIARCH/gnunet/libexec */
   if ( (size > strlen ("/gnunet/libexec/")) &&
        (0 == strcmp ("/gnunet/libexec/",
 		     &lnk[size - strlen ("/gnunet/libexec/")])) )
@@ -350,13 +350,13 @@ get_path_from_PATH ()
 
 
 /**
- * Try to obtain the installation path using the "GNUNET_PREFIX" environment
+ * Try to obtain the installation path using the "GNUNET_GTK_PREFIX" environment
  * variable.
  *
  * @return NULL on error (environment variable not set)
  */
 static char *
-get_path_from_GNUNET_PREFIX ()
+get_path_from_GNUNET_GTK_PREFIX ()
 {
   const char *p;
 
@@ -378,7 +378,7 @@ os_get_gnunet_path ()
 {
   char *ret;
 
-  ret = get_path_from_GNUNET_PREFIX ();
+  ret = get_path_from_GNUNET_GTK_PREFIX ();
   if (ret != NULL)
     return ret;
 #if LINUX
@@ -407,9 +407,9 @@ os_get_gnunet_path ()
     return ret;
   /* other attempts here */
   GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-              _
-              ("Could not determine installation path for %s.  Set `%s' environment variable.\n"),
-              "gnunet-gtk", "GNUNET_GTK_PREFIX");
+              _("Could not determine installation path for %s.  Set `%s' environment variable.\n"),
+              "gnunet-gtk",
+              "GNUNET_GTK_PREFIX");
   return NULL;
 }
 
@@ -427,17 +427,17 @@ os_get_exec_path ()
   ret = NULL;
 #if LINUX
   ret = get_path_from_proc_exe ();
-  if (ret != NULL)
+  if (NULL != ret)
     return ret;
 #endif
 #if WINDOWS
   ret = get_path_from_module_filename ();
-  if (ret != NULL)
+  if (NULL != ret)
     return ret;
 #endif
 #if DARWIN
   ret = get_path_from_NSGetExecutablePath ();
-  if (ret != NULL)
+  if (NULL != ret)
     return ret;
 #endif
   /* other attempts here */
@@ -448,7 +448,7 @@ os_get_exec_path ()
 
 /**
  * @brief get the path to a specific GNUnet installation directory or,
- * with GNUNET_IPK_SELF_PREFIX, the current running apps installation directory
+ * with #GNUNET_OS_IPK_SELF_PREFIX, the current running apps installation directory
  * @author Milan
  * @return a pointer to the dir path (to be freed by the caller)
  */
@@ -459,6 +459,8 @@ GNUNET_GTK_installation_get_path (enum GNUNET_OS_InstallationPathKind dirkind)
   const char *dirname;
   char *execpath = NULL;
   char *tmp;
+  char *multiarch;
+  char *libdir;
   int isbasedir;
 
   /* if wanted, try to get the current app's bin/ */
@@ -467,45 +469,56 @@ GNUNET_GTK_installation_get_path (enum GNUNET_OS_InstallationPathKind dirkind)
 
   /* try to get GNUnet's bin/ or lib/, or if previous was unsuccessful some
    * guess for the current app */
-  if (execpath == NULL)
+  if (NULL == execpath)
     execpath = os_get_gnunet_path ();
 
   if (NULL == execpath)
     return NULL;
 
   n = strlen (execpath);
-  if (n == 0)
+  if (0 == n)
   {
     /* should never happen, but better safe than sorry */
     GNUNET_free (execpath);
     return NULL;
   }
   /* remove filename itself */
-  while ((n > 1) && (execpath[n - 1] == DIR_SEPARATOR))
+  while ((n > 1) && (DIR_SEPARATOR == execpath[n - 1]))
     execpath[--n] = '\0';
 
   isbasedir = 1;
-  if ((n > 5) &&
-      ((0 == strcasecmp (&execpath[n - 5], "lib32")) ||
-       (0 == strcasecmp (&execpath[n - 5], "lib64"))))
+  if ((n > 6) &&
+      ((0 == strcasecmp (&execpath[n - 6], "/lib32")) ||
+       (0 == strcasecmp (&execpath[n - 6], "/lib64"))))
   {
     if ( (GNUNET_OS_IPK_LIBDIR != dirkind) &&
 	 (GNUNET_OS_IPK_LIBEXECDIR != dirkind) )
     {
       /* strip '/lib32' or '/lib64' */
-      execpath[n - 5] = '\0';
-      n -= 5;
+      execpath[n - 6] = '\0';
+      n -= 6;
     }
     else
       isbasedir = 0;
   }
-  else if ((n > 3) &&
-           ((0 == strcasecmp (&execpath[n - 3], "bin")) ||
-            (0 == strcasecmp (&execpath[n - 3], "lib"))))
+  else if ((n > 4) &&
+           ((0 == strcasecmp (&execpath[n - 4], "/bin")) ||
+            (0 == strcasecmp (&execpath[n - 4], "/lib"))))
   {
     /* strip '/bin' or '/lib' */
-    execpath[n - 3] = '\0';
-    n -= 3;
+    execpath[n - 4] = '\0';
+    n -= 4;
+  }
+  multiarch = NULL;
+  if (NULL != (libdir = strstr (execpath, "/lib/")))
+  {
+    /* test for multi-arch path of the form "PREFIX/lib/MULTIARCH/";
+       here we need to re-add 'multiarch' to lib and libexec paths later! */
+    multiarch = &libdir[5];
+    if (NULL == strchr (multiarch, '/'))
+      libdir[0] = '\0'; /* Debian multiarch format, cut of from 'execpath' but preserve in multicarch */
+    else
+      multiarch = NULL; /* maybe not, multiarch still has a '/', which is not OK */
   }
   /* in case this was a directory named foo-bin, remove "foo-" */
   while ((n > 1) && (execpath[n - 1] == DIR_SEPARATOR))
@@ -522,85 +535,128 @@ GNUNET_GTK_installation_get_path (enum GNUNET_OS_InstallationPathKind dirkind)
   case GNUNET_OS_IPK_LIBDIR:
     if (isbasedir)
     {
-      dirname =
-          DIR_SEPARATOR_STR "lib" DIR_SEPARATOR_STR "gnunet-gtk" DIR_SEPARATOR_STR;
-      tmp = GNUNET_malloc (strlen (execpath) + strlen (dirname) + 1);
-      sprintf (tmp, "%s%s", execpath, dirname);
-      if ( (GNUNET_YES !=
-	    GNUNET_DISK_directory_test (tmp, GNUNET_YES)) &&
-	   (4 == sizeof (void *)) )
+      GNUNET_asprintf (&tmp,
+                       "%s%s%s%s%s",
+                       execpath,
+                       DIR_SEPARATOR_STR "lib",
+                       (NULL != multiarch) ? DIR_SEPARATOR_STR : "",
+                       (NULL != multiarch) ? multiarch : "",
+                       DIR_SEPARATOR_STR "gnunet" DIR_SEPARATOR_STR);
+      if (GNUNET_YES ==
+          GNUNET_DISK_directory_test (tmp, GNUNET_YES))
+      {
+        GNUNET_free (execpath);
+        return tmp;
+      }
+      GNUNET_free (tmp);
+      tmp = NULL;
+      if (4 == sizeof (void *))
       {
-	GNUNET_free (tmp);
 	dirname =
 	  DIR_SEPARATOR_STR "lib32" DIR_SEPARATOR_STR "gnunet-gtk" DIR_SEPARATOR_STR;
-	tmp = GNUNET_malloc (strlen (execpath) + strlen (dirname) + 1);
-	sprintf (tmp, "%s%s", execpath, dirname);
+	GNUNET_asprintf (&tmp,
+                         "%s%s",
+                         execpath,
+                         dirname);
       }
-      if ( (GNUNET_YES !=
-	    GNUNET_DISK_directory_test (tmp, GNUNET_YES)) &&
-	   (8 == sizeof (void *)) )
+      if (8 == sizeof (void *))
       {
 	dirname =
 	  DIR_SEPARATOR_STR "lib64" DIR_SEPARATOR_STR "gnunet-gtk" DIR_SEPARATOR_STR;
+	GNUNET_asprintf (&tmp,
+                         "%s%s",
+                         execpath,
+                         dirname);
+      }
+      if ( (NULL != tmp) &&
+           (GNUNET_YES ==
+            GNUNET_DISK_directory_test (tmp, GNUNET_YES)) )
+      {
+        GNUNET_free (execpath);
+        return tmp;
       }
       GNUNET_free (tmp);
     }
-    else
-      dirname = DIR_SEPARATOR_STR "gnunet-gtk" DIR_SEPARATOR_STR;
+    dirname = DIR_SEPARATOR_STR "gnunet-gtk" DIR_SEPARATOR_STR;
     break;
   case GNUNET_OS_IPK_DATADIR:
     dirname =
-        DIR_SEPARATOR_STR "share" DIR_SEPARATOR_STR "gnunet-gtk"
-        DIR_SEPARATOR_STR;
-    break;
-  case GNUNET_OS_IPK_ICONDIR:
-    dirname =
-        DIR_SEPARATOR_STR "share" DIR_SEPARATOR_STR "icons" DIR_SEPARATOR_STR;
+        DIR_SEPARATOR_STR "share" DIR_SEPARATOR_STR "gnunet-gtk" DIR_SEPARATOR_STR;
     break;
   case GNUNET_OS_IPK_LOCALEDIR:
     dirname =
         DIR_SEPARATOR_STR "share" DIR_SEPARATOR_STR "locale" DIR_SEPARATOR_STR;
     break;
+  case GNUNET_OS_IPK_ICONDIR:
+    dirname =
+        DIR_SEPARATOR_STR "share" DIR_SEPARATOR_STR "icons" DIR_SEPARATOR_STR;
+    break;
+  case GNUNET_OS_IPK_DOCDIR:
+    dirname =
+        DIR_SEPARATOR_STR "share" DIR_SEPARATOR_STR "doc" DIR_SEPARATOR_STR \
+        "gnunet" DIR_SEPARATOR_STR;
+    break;
   case GNUNET_OS_IPK_LIBEXECDIR:
     if (isbasedir)
     {
       dirname =
-        DIR_SEPARATOR_STR "lib" DIR_SEPARATOR_STR "gnunet-gtk" DIR_SEPARATOR_STR \
-        "libexec" DIR_SEPARATOR_STR;
-      tmp = GNUNET_malloc (strlen (execpath) + strlen (dirname) + 1);
-      sprintf (tmp, "%s%s", execpath, dirname);
-      if ( (GNUNET_YES !=
-	    GNUNET_DISK_directory_test (tmp, GNUNET_YES)) &&
-	   (4 == sizeof (void *)) )
+        DIR_SEPARATOR_STR "gnunet-gtk" DIR_SEPARATOR_STR "libexec" DIR_SEPARATOR_STR;
+      GNUNET_asprintf (&tmp,
+                       "%s%s%s%s",
+                       execpath,
+                       DIR_SEPARATOR_STR "lib" DIR_SEPARATOR_STR,
+                       (NULL != multiarch) ? multiarch : "",
+                       dirname);
+      if (GNUNET_YES ==
+          GNUNET_DISK_directory_test (tmp, GNUNET_YES))
+      {
+        GNUNET_free (execpath);
+        return tmp;
+      }
+      GNUNET_free (tmp);
+      tmp = NULL;
+      if (4 == sizeof (void *))
       {
-	GNUNET_free (tmp);
 	dirname =
 	  DIR_SEPARATOR_STR "lib32" DIR_SEPARATOR_STR "gnunet-gtk" DIR_SEPARATOR_STR \
 	  "libexec" DIR_SEPARATOR_STR;
-	tmp = GNUNET_malloc (strlen (execpath) + strlen (dirname) + 1);
-	sprintf (tmp, "%s%s", execpath, dirname);
+	GNUNET_asprintf (&tmp,
+                         "%s%s",
+                         execpath,
+                         dirname);
       }
-      if ( (GNUNET_YES !=
-	    GNUNET_DISK_directory_test (tmp, GNUNET_YES)) &&
-	   (8 == sizeof (void *)) )
+      if (8 == sizeof (void *))
       {
 	dirname =
 	  DIR_SEPARATOR_STR "lib64" DIR_SEPARATOR_STR "gnunet-gtk" DIR_SEPARATOR_STR \
 	  "libexec" DIR_SEPARATOR_STR;
+	GNUNET_asprintf (&tmp,
+                         "%s%s",
+                         execpath,
+                         dirname);
       }
+      if ( (NULL != tmp) &&
+           (GNUNET_YES ==
+            GNUNET_DISK_directory_test (tmp, GNUNET_YES)) )
+      {
+        GNUNET_free (execpath);
+        return tmp;
+      }
+
       GNUNET_free (tmp);
     }
-    else
-      dirname =
-        DIR_SEPARATOR_STR "gnunet-gtk" DIR_SEPARATOR_STR \
-        "libexec" DIR_SEPARATOR_STR;
+    dirname =
+      DIR_SEPARATOR_STR "gnunet-gtk" DIR_SEPARATOR_STR \
+      "libexec" DIR_SEPARATOR_STR;
     break;
   default:
     GNUNET_free (execpath);
     return NULL;
   }
-  tmp = GNUNET_malloc (strlen (execpath) + strlen (dirname) + 1);
-  sprintf (tmp, "%s%s", execpath, dirname);
+  GNUNET_asprintf (&tmp,
+                   "%s%s",
+                   execpath,
+                   dirname);
   GNUNET_free (execpath);
   return tmp;
 }
