@@ -4,7 +4,7 @@
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
-     by the Free Software Foundation; either version 2, or (at your
+     by the Free Software Foundation; either version 3, or (at your
      option) any later version.
 
      GNUnet is distributed in the hope that it will be useful, but
@@ -19,7 +19,7 @@
 */
 
 /**
- * @file src/gnunet-setup-hostlist-editing.c
+ * @file src/setup/gnunet-setup-hostlist-editing.c
  * @brief allow editing of the hostlist
  * @author Christian Grothoff
  */
@@ -36,8 +36,8 @@
  * @param user_data not used
  */
 void
-GNUNET_setup_hostlist_url_cellrenderertext_edited_cb (GtkCellRendererText *
-                                                      renderer, gchar * path,
+GNUNET_setup_hostlist_url_cellrenderertext_edited_cb (GtkCellRendererText *renderer,
+                                                      gchar * path,
                                                       gchar * new_text,
                                                       gpointer user_data)
 {
@@ -48,20 +48,20 @@ GNUNET_setup_hostlist_url_cellrenderertext_edited_cb (GtkCellRendererText *
 
   ls = GTK_LIST_STORE (GNUNET_SETUP_get_object
                        ("GNUNET_setup_hostlist_url_liststore"));
-  if (ls == NULL)
+  if (NULL == ls)
   {
     GNUNET_break (0);
     return;
   }
-  if (TRUE !=
-      gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (ls), &old, path))
+  if (! gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (ls), &old, path))
   {
     GNUNET_break (0);
     return;
   }
-  gtk_tree_model_get (GTK_TREE_MODEL (ls), &old, 0, &oldtext, -1);
-  fprintf (stderr, "Edited to `%s'\n", new_text);
-  if (strlen (oldtext) == 0)
+  gtk_tree_model_get (GTK_TREE_MODEL (ls), &old,
+                      GNUNET_GTK_SETUP_HOSTLIST_URL_MC_URL, &oldtext,
+                      -1);
+  if (0 == strlen (oldtext))
   {
     gtk_list_store_insert_before (ls, &iter, &old);
     gtk_list_store_set (ls, &iter,
