@@ -4,7 +4,7 @@
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
-     by the Free Software Foundation; either version 2, or (at your
+     by the Free Software Foundation; either version 3, or (at your
      option) any later version.
 
      GNUnet is distributed in the hope that it will be useful, but
@@ -25,7 +25,9 @@
  */
 #include "gnunet-setup.h"
 #include "gnunet-setup-options.h"
+#include "gnunet-setup-exit-services.h"
 #include <gnunet/gnunet_util_lib.h>
+#include <gnunet/gnunet_tun_lib.h>
 #include <gdk/gdkkeysyms.h>
 
 
@@ -79,7 +81,7 @@ struct PortSpecification
  * @param value value as a string
  * @param widget widget to initialize
  * @param cfg configuration handle
- * @return GNUNET_OK on success, GNUNET_SYSERR if there was a problem
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR if there was a problem
  */
 static int
 load_yes_no (const void *cls, const char *section, const char *option,
@@ -106,7 +108,7 @@ load_yes_no (const void *cls, const char *section, const char *option,
  * @param option option name
  * @param widget widget to initialize
  * @param cfg configuration handle to update
- * @return GNUNET_OK on success, GNUNET_SYSERR if there was a problem
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR if there was a problem
  */
 static int
 save_yes_no (const void *cls, const char *section, const char *option,
@@ -134,7 +136,7 @@ save_yes_no (const void *cls, const char *section, const char *option,
  * @param value value as a string
  * @param widget widget to initialize
  * @param cfg configuration handle
- * @return GNUNET_OK on success, GNUNET_SYSERR if there was a problem
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR if there was a problem
  */
 static int
 load_filename (const void *cls, const char *section, const char *option,
@@ -159,17 +161,20 @@ load_filename (const void *cls, const char *section, const char *option,
  * @param option option name
  * @param widget widget to initialize
  * @param cfg configuration handle to update
- * @return GNUNET_OK on success, GNUNET_SYSERR if there was a problem
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR if there was a problem
  */
 static int
-save_filename (const void *cls, const char *section, const char *option,
-               GObject * widget, struct GNUNET_CONFIGURATION_Handle *cfg)
+save_filename (const void *cls,
+               const char *section,
+               const char *option,
+               GObject * widget,
+               struct GNUNET_CONFIGURATION_Handle *cfg)
 {
   GtkFileChooser *chooser;
   gchar *fn;
 
   chooser = GTK_FILE_CHOOSER (widget);
-  if (chooser == NULL)
+  if (NULL == chooser)
     return GNUNET_SYSERR;
   fn = gtk_file_chooser_get_filename (chooser);
   if (fn == NULL)
@@ -199,7 +204,7 @@ load_text (const void *cls, const char *section, const char *option,
   GtkEntry *entry;
 
   entry = GTK_ENTRY (widget);
-  if (entry == NULL)
+  if (NULL == entry)
     return GNUNET_SYSERR;
   gtk_entry_set_text (entry, value);
   return GNUNET_OK;
@@ -214,7 +219,7 @@ load_text (const void *cls, const char *section, const char *option,
  * @param option option name
  * @param widget widget to initialize
  * @param cfg configuration handle to update
- * @return GNUNET_OK on success, GNUNET_SYSERR if there was a problem
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR if there was a problem
  */
 static int
 save_text (const void *cls, const char *section, const char *option,
@@ -224,7 +229,7 @@ save_text (const void *cls, const char *section, const char *option,
   const gchar *txt;
 
   entry = GTK_ENTRY (widget);
-  if (entry == NULL)
+  if (NULL == entry)
     return GNUNET_SYSERR;
   txt = gtk_entry_get_text (entry);
   GNUNET_CONFIGURATION_set_value_string (cfg, section, option, txt);
@@ -267,7 +272,7 @@ load_combo_text (const void *cls, const char *section, const char *option,
  * @param option option name
  * @param widget widget to initialize
  * @param cfg configuration handle to update
- * @return GNUNET_OK on success, GNUNET_SYSERR if there was a problem
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR if there was a problem
  */
 static int
 save_combo_text (const void *cls, const char *section, const char *option,
@@ -296,7 +301,7 @@ save_combo_text (const void *cls, const char *section, const char *option,
  * @param value value as a string
  * @param widget widget to initialize
  * @param cfg configuration handle
- * @return GNUNET_OK on success, GNUNET_SYSERR if there was a problem
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR if there was a problem
  */
 static int
 load_number (const void *cls, const char *section, const char *option,
@@ -324,7 +329,7 @@ load_number (const void *cls, const char *section, const char *option,
  * @param option option name
  * @param widget widget to initialize
  * @param cfg configuration handle to update
- * @return GNUNET_OK on success, GNUNET_SYSERR if there was a problem
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR if there was a problem
  */
 static int
 save_number (const void *cls, const char *section, const char *option,
@@ -495,6 +500,104 @@ highlight_port_collisions (const void *cls,
 }
 
 
+/**
+ * Check IPv4 exit policy for syntactic correctness.
+ *
+ * @param cls closure (unused)
+ * @param widget widget whose state was changed
+ */
+static void
+validate_v4_policy (const void *cls,
+                    GObject *widget)
+{
+  GtkEntry *entry;
+  GdkColor color;
+  GdkColor *pcolor;
+  gboolean invalid;
+  const char *text;
+  char *r;
+  char *tooltip;
+
+  entry = GTK_ENTRY (widget);
+  text = gtk_entry_get_text (entry);
+  r = GNUNET_TUN_ipv4policy2regex (text);
+  invalid =  ( (strlen (text) > 0) &&
+               ( (NULL == r) ||
+                 (text[strlen(text)-1] != ';') ) );
+  gdk_color_parse (INVALID_INPUT_COLOR, &color);
+  if (invalid)
+  {
+    pcolor = &color;
+    GNUNET_asprintf (&tooltip,
+                     _("Invalid policy."));
+  }
+  else
+  {
+    pcolor = NULL;
+    tooltip = GNUNET_strdup ("");
+  }
+  gtk_widget_modify_bg (GTK_WIDGET (widget),
+                        GTK_STATE_NORMAL, pcolor);
+  gtk_widget_modify_bg (GTK_WIDGET (widget),
+                        GTK_STATE_ACTIVE, pcolor);
+  gtk_widget_modify_bg (GTK_WIDGET (widget),
+                        GTK_STATE_SELECTED, pcolor);
+  gtk_widget_set_tooltip_text (GTK_WIDGET (widget),
+                               tooltip);
+  GNUNET_free (tooltip);
+  GNUNET_free_non_null (r);
+}
+
+
+/**
+ * Check IPv6 exit policy for syntactic correctness.
+ *
+ * @param cls closure (unused)
+ * @param widget widget whose state was changed
+ */
+static void
+validate_v6_policy (const void *cls,
+                    GObject *widget)
+{
+  GtkEntry *entry;
+  GdkColor color;
+  GdkColor *pcolor;
+  gboolean invalid;
+  const char *text;
+  char *r;
+  char *tooltip;
+
+  entry = GTK_ENTRY (widget);
+  text = gtk_entry_get_text (entry);
+  r = GNUNET_TUN_ipv6policy2regex (text);
+  invalid =  ( (strlen (text) > 0) &&
+               ( (NULL == r) ||
+                 (text[strlen(text)-1] != ';') ) );
+  gdk_color_parse (INVALID_INPUT_COLOR, &color);
+  if (invalid)
+  {
+    pcolor = &color;
+    GNUNET_asprintf (&tooltip,
+                     _("Invalid policy."));
+  }
+  else
+  {
+    pcolor = NULL;
+    tooltip = GNUNET_strdup ("");
+  }
+  gtk_widget_modify_bg (GTK_WIDGET (widget),
+                          GTK_STATE_NORMAL, pcolor);
+  gtk_widget_modify_bg (GTK_WIDGET (widget),
+                          GTK_STATE_ACTIVE, pcolor);
+  gtk_widget_modify_bg (GTK_WIDGET (widget),
+                        GTK_STATE_SELECTED, pcolor);
+  gtk_widget_set_tooltip_text (GTK_WIDGET (widget),
+                               tooltip);
+  GNUNET_free (tooltip);
+  GNUNET_free_non_null (r);
+}
+
+
 /**
  * Initialize a toggle button based on the existence of a word
  * in an option value.
@@ -505,7 +608,7 @@ highlight_port_collisions (const void *cls,
  * @param value value as a string
  * @param widget widget to initialize
  * @param cfg configuration handle
- * @return GNUNET_OK on success, GNUNET_SYSERR if there was a problem
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR if there was a problem
  */
 static int
 load_option_list (const void *cls, const char *section, const char *option,
@@ -547,7 +650,7 @@ load_option_list (const void *cls, const char *section, const char *option,
  * @param option option name
  * @param widget widget to initialize
  * @param cfg configuration handle to update
- * @return GNUNET_OK on success, GNUNET_SYSERR if there was a problem
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR if there was a problem
  */
 static int
 save_option_list (const void *cls, const char *section, const char *option,
@@ -627,7 +730,7 @@ GNUNET_setup_treeview_key_press_event_cb (GtkTreeView * tv, GdkEventKey * event,
  * @param value value as a string
  * @param widget widget to initialize
  * @param cfg configuration handle
- * @return GNUNET_OK on success, GNUNET_SYSERR if there was a problem
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR if there was a problem
  */
 static int
 load_string_list_store (const void *cls, const char *section,
@@ -668,7 +771,7 @@ load_string_list_store (const void *cls, const char *section,
  * @param option option name (NULL)
  * @param widget the cell renderer
  * @param cfg configuration handle to update
- * @return GNUNET_OK on success, GNUNET_SYSERR if there was a problem
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR if there was a problem
  */
 static int
 save_string_list_store (const void *cls, const char *section,
@@ -750,6 +853,33 @@ static struct GNUNET_SETUP_VisibilitySpecification hide_exit_options[] = {
 };
 
 
+/**
+ * Hide DNS "exit" options if DNS exit is not in use.
+ */
+static struct GNUNET_SETUP_VisibilitySpecification hide_dns_exit_options[] = {
+  {"GNUNET_setup_dns_resolver_hbox", "^YES$", NULL},
+  {NULL, NULL, NULL}
+};
+
+
+/**
+ * Hide IPv4 "exit" options if IPv4 exit is not in use.
+ */
+static struct GNUNET_SETUP_VisibilitySpecification hide_v4_exit_options[] = {
+  {"GNUNET_SETUP_exit_policy_v4_hbox", "^YES$", NULL},
+  {NULL, NULL, NULL}
+};
+
+
+/**
+ * Hide IPv6 "exit" options if IPv6 exit is not in use.
+ */
+static struct GNUNET_SETUP_VisibilitySpecification hide_v6_exit_options[] = {
+  {"GNUNET_SETUP_exit_policy_v6_hbox", "^YES$", NULL},
+  {NULL, NULL, NULL}
+};
+
+
 /**
  * Hide "hostlist" server options if hostlist server is not in use.
  */
@@ -781,10 +911,9 @@ static struct GNUNET_SETUP_VisibilitySpecification hide_vpn_tab[] = {
 
 
 /**
- * Hide "gads" and "namestore" tabs if GNS not active.
+ * Hide "namestore" tab if GNS not active.
  */
 static struct GNUNET_SETUP_VisibilitySpecification hide_gns_tabs[] = {
-  {"GNUNET_setup_gads_vbox", "(^| )gns($| )", NULL},
   {"GNUNET_setup_namestore_vbox", "(^| )gns($| )", NULL},
   {NULL, NULL, NULL}
 };
@@ -977,18 +1106,6 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    NULL, NULL,
    hide_min_connected_friends},
 
-  {
-   "GNUNET_setup_friends_filechooserbutton",
-   "selection-changed",
-   "topology",
-   "FRIENDS",
-   gettext_noop ("Friends file containing the list of friendly peers"),
-   "https://gnunet.org/configuration-f2f",
-   &load_filename,
-   &save_filename, NULL,
-   NULL, NULL,
-   NULL},
-
   {
    "GNUNET_setup_minimum_friends_spinbutton",
    "value-changed",
@@ -1386,7 +1503,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    &save_number, NULL,
    NULL, NULL,
    NULL},
-   
+
   {
    "GNUNET_setup_transport_udp_advertised_port_spinbutton",
    "value-changed",
@@ -1787,7 +1904,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "GNUNET_setup_vpn_interface_v6_mask_spinbutton",
    "value-changed",
    "vpn",
-   "IPV6MASK",
+   "IPV6PREFIX",
    gettext_noop ("IPv6 network prefix length to use for the VPN interface"),
    "https://gnunet.org/configuration-vpn",
    &load_number,
@@ -1814,8 +1931,8 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
   {
    "GNUNET_setup_dns_resolver_ip_entry",
    "changed",
-   "dns",
-   "DNS_EXIT",
+   "exit",
+   "DNS_RESOLVER",
    gettext_noop
    ("IP address of the external DNS resolver to use (values from your resolve.conf are usually appropriate))"),
    "https://gnunet.org/configuration-exit",
@@ -1827,21 +1944,21 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
   {
    "GNUNET_setup_dns_enable_exit_checkbutton",
    "toggled",
-   "dns",
-   "PROVIDE_EXIT",
+   "exit",
+   "EXIT_DNS",
    gettext_noop
    ("Allow other peers to perform DNS resolutions using your Internet connection"),
    "https://gnunet.org/configuration-dns",
    &load_yes_no,
    &save_yes_no, NULL,
    NULL, NULL,
-   NULL},
+   hide_dns_exit_options},
 
   {
    "GNUNET_setup_exit_interface_name_entry",
    "changed",
    "exit",
-   "IFNAME",
+   "TUN_IFNAME",
    gettext_noop
    ("Name of the virtual interface the GNUnet exit service should create for traffic exiting the VPN to the Internet"),
    "https://gnunet.org/configuration-exit",
@@ -1890,7 +2007,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "GNUNET_setup_exit_interface_v6_mask_spinbutton",
    "value-changed",
    "exit",
-   "IPV6MASK",
+   "IPV6PREFIX",
    gettext_noop
    ("IPv6 network prefix length to use for the Exit interface"),
    "https://gnunet.org/configuration-exit",
@@ -1911,7 +2028,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    &load_yes_no,
    &save_yes_no, NULL,
    NULL, NULL,
-   NULL},
+   hide_v4_exit_options},
 
   {
    "GNUNET_setup_exit_enable_ipv6_exit_checkbutton",
@@ -1924,9 +2041,39 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    &load_yes_no,
    &save_yes_no, NULL,
    NULL, NULL,
+   hide_v6_exit_options},
+
+
+  {
+   "GNUNET_SETUP_exit_policy_v4_entry",
+   "changed",
+   "exit",
+   "EXIT_RANGE_IPV4_POLICY",
+   gettext_noop
+   ("Which IPv4 addresses and ports do you allow other users to send traffic towards (via the Exit interface)"),
+   "https://gnunet.org/configuration-exit",
+   &load_text,
+   &save_text, NULL,
+   &validate_v4_policy, NULL,
    NULL},
 
 
+  {
+   "GNUNET_SETUP_exit_policy_v6_entry",
+   "changed",
+   "exit",
+   "EXIT_RANGE_IPV6_POLICY",
+   gettext_noop
+   ("Which IPv6 addresses and ports do you allow other users to send traffic towards (via the Exit interface)"),
+   "https://gnunet.org/configuration-exit",
+   &load_text,
+   &save_text, NULL,
+   &validate_v6_policy, NULL,
+   NULL},
+
+
+
+
   /* Namestore TAB */
 
   {
@@ -1966,7 +2113,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    NULL},
 
 
-  /* GADS/GNS */
+  /* GNS */
 
   {
    "GNUNET_setup_general_services_gns_checkbutton",
@@ -1981,30 +2128,79 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    hide_gns_tabs},
 
 
+  /* EXIT services */
+
   {
-   "GNUNET_setup_gns_hijack_checkbutton",
-   "toggled",
-   "gns",
-   "HIJACK_DNS",
-   gettext_noop ("Should DNS queries be intercepted using iptables?"),
-   "https://gnunet.org/gnunet-dns-setup",
-   &load_yes_no,
-   &save_yes_no, NULL,
+   "GNUNET_setup_hosted_service_treeview",
+   NULL,
+   NULL,
+   NULL,
+   gettext_noop
+   ("Specification of .gnunet hosted services"),
+   "https://gnunet.org/configuration-dns",
+   &load_hosted_service_configuration,
+   NULL, NULL,
    NULL, NULL,
    NULL},
 
   {
-   "GNUNET_setup_gns_auto_import_checkbutton",
-   "toggled",
-   "gns",
-   "AUTO_IMPORT_PKEY",
-   gettext_noop ("Should names be automatically learned and placed into the 'shorten' Zone?"),
-   "https://gnunet.org/configuration-gns-shortening",
-   &load_yes_no,
-   &save_yes_no, NULL,
-   NULL, NULL,
+   "GNUNET_SETUP_hosted_service_identifier_cellrenderertext",
+   "editing-started",
+   NULL,
+   NULL,
+   NULL,
+   "https://gnunet.org/configuration-dns",
+   NULL,
+   &hosted_service_name_install_edited_handler,
+   NULL,
+   NULL,
+   NULL,
    NULL},
 
+  {
+   "GNUNET_SETUP_hosted_service_is_udp_cellrenderertoggle",
+   "toggled",
+   NULL,
+   NULL,
+   NULL,
+   "https://gnunet.org/configuration-dns",
+   NULL,
+   &hosted_service_is_udp_install_toggled_handler,
+   NULL,
+   NULL,
+   NULL,
+   NULL},
+
+  {
+   "GNUNET_SETUP_hosted_service_port_cellrenderertext",
+   "editing-started",
+   NULL,
+   NULL,
+   NULL,
+   "https://gnunet.org/configuration-dns",
+   NULL,
+   &hosted_service_visible_port_install_edited_handler,
+   NULL,
+   NULL,
+   NULL,
+   NULL},
+
+  {
+   "GNUNET_SETUP_hosted_service_destination_cellrenderertext",
+   "editing-started",
+   NULL,
+   NULL,
+   NULL,
+   "https://gnunet.org/configuration-dns",
+   NULL,
+   &hosted_service_destination_install_edited_handler,
+   NULL,
+   NULL,
+   NULL,
+   NULL},
+
+
+
   /* END of list */
 
   {NULL, NULL, NULL, NULL, NULL,
