@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2010, 2012 Christian Grothoff (and other contributing authors)
+     (C) 2010, 2012, 2013 Christian Grothoff (and other contributing authors)
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -142,7 +142,7 @@ next_phase (struct GNUNET_SetupAutoContext *ac);
 /**
  * Update the ICMP server button based on the result.
  *
- * @param on GNUNET_YES to enable, GNUNET_NO to disable
+ * @param on #GNUNET_YES to enable, #GNUNET_NO to disable
  */
 static void
 update_icmp_server_enable_button (int on)
@@ -166,10 +166,12 @@ update_icmp_server_enable_button (int on)
  * Clean up and update GUI (with success).
  *
  * @param cls closure (unused)
- * @param success currently always GNUNET_OK
+ * @param success currently always #GNUNET_OK
+ * @param emsg error message, NULL on success
  */
 static void
-result_callback (void *cls, int success)
+result_callback (void *cls, int success,
+                 const char *emsg)
 {
   struct GNUNET_SetupAutoContext *ac = cls;
 
@@ -197,7 +199,8 @@ result_callback (void *cls, int success)
  * @param tc scheduler callback
  */
 static void
-fail_timeout (void *cls, const struct GNUNET_SCHEDULER_TaskContext *tc)
+fail_timeout (void *cls,
+              const struct GNUNET_SCHEDULER_TaskContext *tc)
 {
   struct GNUNET_SetupAutoContext *ac = cls;
 
@@ -221,7 +224,8 @@ fail_timeout (void *cls, const struct GNUNET_SCHEDULER_TaskContext *tc)
  * @param tc scheduler context
  */
 static void
-reversal_test (void *cls, const struct GNUNET_SCHEDULER_TaskContext *tc)
+reversal_test (void *cls,
+               const struct GNUNET_SCHEDULER_TaskContext *tc)
 {
   struct GNUNET_SetupAutoContext *ac = cls;
 
@@ -257,9 +261,12 @@ test_online (struct GNUNET_SetupAutoContext *ac)
  *
  * @param cls closure with our setup context
  * @param addr the address, NULL on errors
+ * @param emsg error message, NULL on success
  */
 static void
-set_external_ipv4 (void *cls, const struct in_addr *addr)
+set_external_ipv4 (void *cls,
+                   const struct in_addr *addr,
+                   const char *emsg)
 {
   struct GNUNET_SetupAutoContext *ac = cls;
   char buf[INET_ADDRSTRLEN];
@@ -325,7 +332,7 @@ test_external_ip (struct GNUNET_SetupAutoContext *ac)
  * @param broadcast_addr the broadcast address (can be NULL for unknown or unassigned)
  * @param netmask the network mask (can be NULL for unknown or unassigned))
  * @param addrlen length of the address
- * @return GNUNET_OK to continue iteration, GNUNET_SYSERR to abort
+ * @return #GNUNET_OK to continue iteration, #GNUNET_SYSERR to abort
  */
 static int
 nipo (void *cls, const char *name, int isDefault, const struct sockaddr *addr,
@@ -343,7 +350,7 @@ nipo (void *cls, const char *name, int isDefault, const struct sockaddr *addr,
        (0 != memcmp (&in6addr_loopback,
                      &((struct sockaddr_in6 *)addr)->sin6_addr,
 		     sizeof (struct in6_addr))) &&
-       (! IN6_IS_ADDR_LINKLOCAL(addr)) )
+       (! IN6_IS_ADDR_LINKLOCAL ((const struct sockaddr_in6*) addr)) )
   {
     *have_v6 = GNUNET_YES;
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
