@@ -410,7 +410,7 @@ GNUNET_SETUP_restart_namestore (void *cls,
   }
   namestore =
     GNUNET_OS_start_process (GNUNET_YES, GNUNET_OS_INHERIT_STD_ALL,
-                             NULL, NULL,
+                             NULL, NULL, NULL,
                              "gnunet-service-namestore",
 			     "gnunet-service-namestore", NULL);
 }
@@ -443,7 +443,7 @@ start_resolver (void *cls,
   binary = GNUNET_OS_get_libexec_binary_path ("gnunet-service-resolver");
   resolver =
     GNUNET_OS_start_process (GNUNET_YES, GNUNET_OS_INHERIT_STD_ALL,
-                             NULL,NULL,
+                             NULL,NULL, NULL,
                              binary,
 			     "gnunet-service-resolver", NULL);
   GNUNET_free (binary);
@@ -467,7 +467,7 @@ start_identity (void *cls,
   binary = GNUNET_OS_get_libexec_binary_path ("gnunet-service-identity");
   identity =
     GNUNET_OS_start_process (GNUNET_YES, GNUNET_OS_INHERIT_STD_ALL,
-                             NULL, NULL,
+                             NULL, NULL, NULL,
                              binary,
 			     "gnunet-service-identity", NULL);
   GNUNET_free (binary);
@@ -491,7 +491,7 @@ start_namestore (void *cls,
   binary = GNUNET_OS_get_libexec_binary_path ("gnunet-service-namestore");
   namestore =
     GNUNET_OS_start_process (GNUNET_YES, GNUNET_OS_INHERIT_STD_ALL,
-                             NULL, NULL,
+                             NULL, NULL, NULL,
                              binary,
 			     "gnunet-service-namestore", NULL);
   GNUNET_free (binary);
@@ -513,7 +513,7 @@ try_gksu (const char *username)
 
   proc = GNUNET_OS_start_process (GNUNET_NO,
 				  GNUNET_OS_INHERIT_STD_ALL,
-				  NULL, NULL,
+				  NULL, NULL, NULL,
 				  "gksu",
 				  "-u", username,
 				  "-m", _("Enter YOUR password to run gnunet-setup as user 'gnunet' (assuming 'sudo' allows it)"),
@@ -540,7 +540,7 @@ GNUNET_setup_launch_edit_friends_button_clicked_cb (GtkButton *button,
 
   proc = GNUNET_OS_start_process (GNUNET_NO,
 				  GNUNET_OS_INHERIT_STD_ALL,
-				  NULL, NULL,
+				  NULL, NULL, NULL,
 				  "gnunet-peerinfo-gtk",
 				  "-c", option_cfg_name,
                                   NULL);
