@@ -1,10 +1,10 @@
 /*
      This file is part of GNUnet.
-     (C) 2010 Christian Grothoff (and other contributing authors)
+     (C) 2010, 2013 Christian Grothoff (and other contributing authors)
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
-     by the Free Software Foundation; either version 2, or (at your
+     by the Free Software Foundation; either version 3, or (at your
      option) any later version.
 
      GNUnet is distributed in the hope that it will be useful, but
@@ -19,7 +19,7 @@
 */
 
 /**
- * @file src/gnunet-setup.h
+ * @file src/setup/gnunet-setup.h
  * @brief globals
  * @author Christian Grothoff
  */
@@ -27,7 +27,6 @@
 #define GNUNET_SETUP_H
 
 #include "gnunet_gtk.h"
-#include <gnunet/gnunet_directories.h>
 #include <gnunet/gnunet_util_lib.h>
 #include <gladeui/glade.h>
 #include <gtk/gtk.h>
@@ -39,7 +38,7 @@
 enum GNUNET_GTK_SETUP_HostlistUrlModelColumns
   {
     /**
-     * A gchararray 
+     * A gchararray
      */
     GNUNET_GTK_SETUP_HOSTLIST_URL_MC_URL = 0,
 
@@ -50,38 +49,6 @@ enum GNUNET_GTK_SETUP_HostlistUrlModelColumns
   };
 
 
-/**
- * Columns in the hostlist url setup model.
- */
-enum GNUNET_GTK_SETUP_GnsModelColumns
-  {
-    /**
-     * A gchararray 
-     */
-    GNUNET_GTK_SETUP_GNS_MC_HOSTNAME = 0,
-      
-    /**
-     * A guint
-     */
-    GNUNET_GTK_SETUP_GNS_MC_SOURCEPORT = 1,
-
-    /**
-     * A guint
-     */
-    GNUNET_GTK_SETUP_GNS_MC_TARGETPORT = 2,
-
-    /**
-     * A gchararray 
-     */
-    GNUNET_GTK_SETUP_GNS_MC_TARGETHOSTNAME = 3,
-
-    /**
-     * A gchararray 
-     */
-    GNUNET_GTK_SETUP_GNS_MC_ISUDP = 4,
-  };
-
-
 /**
  * Get an object from the main window.
  *
@@ -95,7 +62,7 @@ GNUNET_SETUP_get_object (const char *name);
 /**
  * Write configuration to dis, (re)start the namestore process and
  * reload the namestore models.
- * 
+ *
  *
  * @param cls closure (unused)
  * @param tc scheduler context (unused)
