@@ -4,7 +4,7 @@
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
-     by the Free Software Foundation; either version 2, or (at your
+     by the Free Software Foundation; either version 3, or (at your
      option) any later version.
 
      GNUnet is distributed in the hope that it will be useful, but
@@ -149,7 +149,7 @@ process_value_update (void *cls, const char *subsystem, const char *name,
   GNUNET_asprintf (&id, "%s: %s", subsystem, name);
   gtk_statistics_update_value (stats, id,
                                GNUNET_TIME_absolute_get_duration
-                               (start_time).rel_value / 1000LL, value);
+                               (start_time).rel_value_us / 1000000LL, value);
   GNUNET_free (id);
   return GNUNET_OK;
 }
@@ -171,7 +171,7 @@ get_object (const char *name)
 /**
  * Actually draw a plot based on collected data.
  *
- * @param widget size and style information for the plot
+ * @param box_name name of the widget to update
  * @param info what to draw
  */
 static void
@@ -261,11 +261,14 @@ run (void *cls, const struct GNUNET_SCHEDULER_TaskContext *tc)
 
   /* setup main window */
   main_window = GTK_WIDGET (get_object ("GNUNET_STATISTICS_GTK_main_window"));
+  main_window = GNUNET_GTK_plug_me ("GNUNET_STATISTICS_GTK_PLUG",
+                                    main_window);
   gtk_window_maximize (GTK_WINDOW (main_window));
-  GNUNET_GTK_tray_icon_create (ml,
-			       GTK_WINDOW (main_window),
-                               "gnunet-gtk" /* FIXME: different icon? */ ,
-                               "gnunet-statistics-gtk");
+  if (NULL == getenv ("GNUNET_STATISTICS_GTK_PLUG"))
+    GNUNET_GTK_tray_icon_create (ml,
+                                 GTK_WINDOW (main_window),
+                                 "gnunet-gtk" /* FIXME: different icon? */ ,
+                                 "gnunet-statistics-gtk");
 
   create_plot ("GNUNET_STATISTICS_GTK_connectivity_box", connection_data);
   create_plot ("GNUNET_STATISTICS_GTK_traffic_box", traffic_data);
